@@ -945,11 +945,15 @@ std::optional<Data::StarGift> FromTL(
 				.releasedBy = releasedBy,
 				.themeUser = themeUser,
 				.nanoTonForResale = FindTonForResale(data.vresell_amount()),
+				.craftChancePermille
+					= data.vcraft_chance_permille().value_or_empty(),
 				.starsForResale = FindStarsForResale(data.vresell_amount()),
 				.starsMinOffer = data.voffer_min_stars().value_or(-1),
 				.number = data.vnum().v,
 				.onlyAcceptTon = data.is_resale_ton_only(),
 				.canBeTheme = data.is_theme_available(),
+				.crafted = data.is_crafted(),
+				.burned = data.is_burned(),
 				.model = *model,
 				.pattern = *pattern,
 				.value = (data.vvalue_amount()
@@ -999,6 +1003,7 @@ std::optional<Data::SavedStarGift> FromTL(
 		unique->exportAt = data.vcan_export_at().value_or_empty();
 		unique->canTransferAt = data.vcan_transfer_at().value_or_empty();
 		unique->canResellAt = data.vcan_resell_at().value_or_empty();
+		unique->canCraftAt = data.vcan_craft_at().value_or_empty();
 	}
 	using Id = Data::SavedStarGiftId;
 	const auto hasUnique = parsed->unique != nullptr;
@@ -1038,6 +1043,20 @@ std::optional<Data::SavedStarGift> FromTL(
 	};
 }
 
+int ParseRarity(const MTPStarGiftAttributeRarity &rarity) {
+	return rarity.match([&](const MTPDstarGiftAttributeRarity &data) {
+		return std::max(data.vpermille().v, 0);
+	}, [&](const MTPDstarGiftAttributeRarityUncommon &) {
+		return int(Data::UniqueGiftRarity::Uncommon);
+	}, [&](const MTPDstarGiftAttributeRarityRare &) {
+		return int(Data::UniqueGiftRarity::Rare);
+	}, [&](const MTPDstarGiftAttributeRarityEpic &) {
+		return int(Data::UniqueGiftRarity::Epic);
+	}, [&](const MTPDstarGiftAttributeRarityLegendary &) {
+		return int(Data::UniqueGiftRarity::Legendary);
+	});
+}
+
 Data::UniqueGiftModel FromTL(
 		not_null<Main::Session*> session,
 		const MTPDstarGiftAttributeModel &data) {
@@ -1045,7 +1064,7 @@ Data::UniqueGiftModel FromTL(
 		.document = session->data().processDocument(data.vdocument()),
 	};
 	result.name = qs(data.vname());
-	result.rarityPermille = data.vrarity_permille().v;
+	result.rarityValue = ParseRarity(data.vrarity());
 	return result;
 }
 
@@ -1057,14 +1076,14 @@ Data::UniqueGiftPattern FromTL(
 	};
 	result.document->overrideEmojiUsesTextColor(true);
 	result.name = qs(data.vname());
-	result.rarityPermille = data.vrarity_permille().v;
+	result.rarityValue = ParseRarity(data.vrarity());
 	return result;
 }
 
 Data::UniqueGiftBackdrop FromTL(const MTPDstarGiftAttributeBackdrop &data) {
 	auto result = Data::UniqueGiftBackdrop{ .id = data.vbackdrop_id().v };
 	result.name = qs(data.vname());
-	result.rarityPermille = data.vrarity_permille().v;
+	result.rarityValue = ParseRarity(data.vrarity());
 	result.centerColor = Ui::ColorFromSerialized(
 		data.vcenter_color());
 	result.edgeColor = Ui::ColorFromSerialized(
