@@ -198,7 +198,7 @@ not_null<Ui::FlatLabel*> CreateWarningLabel(
 		st::createPollWarning);
 	result->setAttribute(Qt::WA_TransparentForMouseEvents);
 	field->changes(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		Ui::PostponeCall(crl::guard(field, [=] {
 			const auto length = field->getLastText().size();
 			const auto value = valueLimit - length;
@@ -246,22 +246,21 @@ Options::Option::Option(
 	InitField(outer, _field, session);
 	_field->setMaxLength(kOptionLimit + kErrorLimit);
 	_field->show();
-	_field->customTab(true);
 
 	_wrap->hide(anim::type::instant);
 
 	_content->widthValue(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		updateFieldGeometry();
 	}, _field->lifetime());
 
 	_field->heightValue(
-	) | rpl::start_with_next([=](int height) {
+	) | rpl::on_next([=](int height) {
 		_content->resize(_content->width(), height);
 	}, _field->lifetime());
 
 	_field->changes(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		Ui::PostponeCall(crl::guard(_field, [=] {
 			if (_hasCorrect) {
 				_correct->toggle(isGood(), anim::type::normal);
@@ -293,7 +292,7 @@ void Options::Option::createShadow() {
 	_shadow.reset(Ui::CreateChild<Ui::PlainShadow>(field().get()));
 	_shadow->show();
 	field()->sizeValue(
-	) | rpl::start_with_next([=](QSize size) {
+	) | rpl::on_next([=](QSize size) {
 		const auto left = st::createPollFieldPadding.left();
 		_shadow->setGeometry(
 			left,
@@ -322,7 +321,7 @@ void Options::Option::createRemove() {
 	_removeAlways = lifetime.make_state<rpl::variable<bool>>(false);
 
 	field->changes(
-	) | rpl::start_with_next([field, toggle] {
+	) | rpl::on_next([field, toggle] {
 		// Don't capture 'this'! Because Option is a value type.
 		*toggle = !field->getLastText().isEmpty();
 	}, field->lifetime());
@@ -331,13 +330,13 @@ void Options::Option::createRemove() {
 		toggle->value(),
 		_removeAlways->value(),
 		_1 || _2
-	) | rpl::start_with_next([=](bool shown) {
+	) | rpl::on_next([=](bool shown) {
 		remove->toggle(shown, anim::type::normal);
 	}, remove->lifetime());
 #endif
 
 	field->widthValue(
-	) | rpl::start_with_next([=](int width) {
+	) | rpl::on_next([=](int width) {
 		remove->moveToRight(
 			st::createPollOptionRemovePosition.x(),
 			st::createPollOptionRemovePosition.y(),
@@ -359,7 +358,7 @@ void Options::Option::createWarning() {
 	rpl::combine(
 		field->sizeValue(),
 		warning->sizeValue()
-	) | rpl::start_with_next([=](QSize size, QSize label) {
+	) | rpl::on_next([=](QSize size, QSize label) {
 		warning->moveToLeft(
 			(size.width()
 				- label.width()
@@ -431,7 +430,7 @@ void Options::Option::enableChooseCorrect(
 		button->entity()->height());
 	button->hide(anim::type::instant);
 	_content->sizeValue(
-	) | rpl::start_with_next([=](QSize size) {
+	) | rpl::on_next([=](QSize size) {
 		const auto left = st::createPollFieldPadding.left();
 		button->moveToLeft(
 			left,
@@ -688,19 +687,19 @@ void Options::addEmptyOption() {
 			QPoint(
 				-st::createPollOptionFieldPremium.textMargins.right(),
 				st::createPollOptionEmojiPositionSkip));
-		emojiToggle->shownValue() | rpl::start_with_next([=](bool shown) {
+		emojiToggle->shownValue() | rpl::on_next([=](bool shown) {
 			if (!shown) {
 				return;
 			}
 			_emojiPanelLifetime.destroy();
 			emojiPanel->selector()->emojiChosen(
-			) | rpl::start_with_next([=](ChatHelpers::EmojiChosen data) {
+			) | rpl::on_next([=](ChatHelpers::EmojiChosen data) {
 				if (field->hasFocus()) {
 					Ui::InsertEmojiAtCursor(field->textCursor(), data.emoji);
 				}
 			}, _emojiPanelLifetime);
 			emojiPanel->selector()->customEmojiChosen(
-			) | rpl::start_with_next([=](ChatHelpers::FileChosen data) {
+			) | rpl::on_next([=](ChatHelpers::FileChosen data) {
 				if (field->hasFocus()) {
 					Data::InsertCustomEmoji(field, data.document);
 				}
@@ -708,30 +707,31 @@ void Options::addEmptyOption() {
 		}, emojiToggle->lifetime());
 	}
 	field->submits(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		const auto index = findField(field);
 		if (_list[index]->isGood() && index + 1 < _list.size()) {
 			_list[index + 1]->setFocus();
 		}
 	}, field->lifetime());
 	field->changes(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		Ui::PostponeCall(crl::guard(field, [=] {
 			validateState();
 		}));
 	}, field->lifetime());
 	field->focusedChanges(
-	) | rpl::filter(rpl::mappers::_1) | rpl::start_with_next([=] {
+	) | rpl::filter(rpl::mappers::_1) | rpl::on_next([=] {
 		_scrollToWidget.fire_copy(field);
 	}, field->lifetime());
 	field->tabbed(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=](not_null<bool*> handled) {
 		const auto index = findField(field);
 		if (index + 1 < _list.size()) {
 			_list[index + 1]->setFocus();
 		} else {
 			_tabbed.fire({});
 		}
+		*handled = true;
 	}, field->lifetime());
 	base::install_event_filter(field, [=](not_null<QEvent*> event) {
 		if (event->type() != QEvent::KeyPress
@@ -753,7 +753,7 @@ void Options::addEmptyOption() {
 	});
 
 	_list.back()->removeClicks(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		Ui::PostponeCall(crl::guard(field, [=] {
 			Expects(!_list.empty());
 
@@ -863,7 +863,6 @@ not_null<Ui::InputField*> CreatePollBox::setupQuestion(
 	InitField(getDelegate()->outerContainer(), question, session);
 	question->setMaxLength(kQuestionLimit + kErrorLimit);
 	question->setSubmitSettings(Ui::InputField::SubmitSettings::Both);
-	question->customTab(true);
 
 	if (isPremium) {
 		using Selector = ChatHelpers::TabbedSelector;
@@ -891,13 +890,13 @@ not_null<Ui::InputField*> CreatePollBox::setupQuestion(
 			emojiPanel,
 			st::createPollOptionFieldPremiumEmojiPosition);
 		emojiPanel->selector()->emojiChosen(
-		) | rpl::start_with_next([=](ChatHelpers::EmojiChosen data) {
+		) | rpl::on_next([=](ChatHelpers::EmojiChosen data) {
 			if (question->hasFocus()) {
 				Ui::InsertEmojiAtCursor(question->textCursor(), data.emoji);
 			}
 		}, emojiToggle->lifetime());
 		emojiPanel->selector()->customEmojiChosen(
-		) | rpl::start_with_next([=](ChatHelpers::FileChosen data) {
+		) | rpl::on_next([=](ChatHelpers::FileChosen data) {
 			if (question->hasFocus()) {
 				Data::InsertCustomEmoji(question, data.document);
 			}
@@ -912,7 +911,7 @@ not_null<Ui::InputField*> CreatePollBox::setupQuestion(
 	rpl::combine(
 		question->geometryValue(),
 		warning->sizeValue()
-	) | rpl::start_with_next([=](QRect geometry, QSize label) {
+	) | rpl::on_next([=](QRect geometry, QSize label) {
 		warning->moveToLeft(
 			(container->width()
 				- label.width()
@@ -968,7 +967,6 @@ not_null<Ui::InputField*> CreatePollBox::setupSolution(
 	));
 	solution->setEditLinkCallback(
 		DefaultEditLinkCallback(_controller->uiShow(), solution));
-	solution->customTab(true);
 
 	const auto warning = CreateWarningLabel(
 		inner,
@@ -978,7 +976,7 @@ not_null<Ui::InputField*> CreatePollBox::setupSolution(
 	rpl::combine(
 		solution->geometryValue(),
 		warning->sizeValue()
-	) | rpl::start_with_next([=](QRect geometry, QSize label) {
+	) | rpl::on_next([=](QRect geometry, QSize label) {
 		warning->moveToLeft(
 			(inner->width()
 				- label.width()
@@ -1048,8 +1046,9 @@ object_ptr<Ui::RpWidget> CreatePollBox::setupContent() {
 			st::createPollLimitPadding));
 
 	question->tabbed(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=](not_null<bool*> handled) {
 		options->focusFirst();
+		*handled = true;
 	}, question->lifetime());
 
 	Ui::AddSkip(container);
@@ -1088,7 +1087,7 @@ object_ptr<Ui::RpWidget> CreatePollBox::setupContent() {
 		rpl::single(quiz->checked()) | rpl::then(quiz->checkedChanges()));
 
 	options->tabbed(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		if (quiz->checked()) {
 			solution->setFocus();
 		} else {
@@ -1097,8 +1096,9 @@ object_ptr<Ui::RpWidget> CreatePollBox::setupContent() {
 	}, question->lifetime());
 
 	solution->tabbed(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=](not_null<bool*> handled) {
 		question->setFocus();
+		*handled = true;
 	}, solution->lifetime());
 
 	quiz->setDisabled(_disabled & PollData::Flag::Quiz);
@@ -1109,14 +1109,14 @@ object_ptr<Ui::RpWidget> CreatePollBox::setupContent() {
 		) | rpl::filter([=](not_null<QEvent*> e) {
 			return (e->type() == QEvent::MouseButtonPress)
 				&& quiz->checked();
-		}) | rpl::start_with_next([show = uiShow()] {
+		}) | rpl::on_next([show = uiShow()] {
 			show->showToast(tr::lng_polls_create_one_answer(tr::now));
 		}, multiple->lifetime());
 	}
 
 	using namespace rpl::mappers;
 	quiz->checkedChanges(
-	) | rpl::start_with_next([=](bool checked) {
+	) | rpl::on_next([=](bool checked) {
 		if (multiple) {
 			if (checked && multiple->checked()) {
 				multiple->setChecked(false);
@@ -1132,7 +1132,7 @@ object_ptr<Ui::RpWidget> CreatePollBox::setupContent() {
 		return !text.isEmpty() && (text.size() <= kQuestionLimit);
 	};
 	question->submits(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		if (isValidQuestion()) {
 			options->focusFirst();
 		}
@@ -1216,12 +1216,12 @@ object_ptr<Ui::RpWidget> CreatePollBox::setupContent() {
 		crl::guard(this, send));
 
 	options->scrollToWidget(
-	) | rpl::start_with_next([=](not_null<QWidget*> widget) {
+	) | rpl::on_next([=](not_null<QWidget*> widget) {
 		scrollToWidget(widget);
 	}, lifetime());
 
 	options->backspaceInFront(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		FocusAtEnd(question);
 	}, lifetime());
 
