@@ -29,7 +29,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "ui/boxes/confirm_box.h"
 #include "ui/boxes/show_or_premium_box.h"
 #include "ui/effects/premium_graphics.h"
-#include "ui/text/text_utilities.h" // Ui::Text::RichLangValue
+#include "ui/text/text_utilities.h" // tr::rich
 #include "ui/toast/toast.h"
 #include "ui/widgets/buttons.h"
 #include "ui/widgets/checkbox.h"
@@ -39,7 +39,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "base/unixtime.h"
 #include "main/main_session.h"
 #include "mtproto/mtproto_config.h"
-#include "settings/settings_premium.h"
+#include "settings/sections/settings_premium.h"
 #include "window/window_session_controller.h"
 #include "info/profile/info_profile_icon.h"
 #include "apiwrap.h"
@@ -191,17 +191,17 @@ void FillUpgradeToPremiumCover(
 	for (auto i = 0; i != names; ++i) {
 		const auto name = userpicUsers[i]->shortName();
 		if (text.empty()) {
-			text = Ui::Text::Bold(name);
+			text = tr::bold(name);
 		} else if (i == names - 1 && !remaining) {
 			text = tr::lng_invite_upgrade_users_few(
 				tr::now,
 				lt_users,
 				text,
 				lt_last,
-				Ui::Text::Bold(name),
-				Ui::Text::RichLangValue);
+				tr::bold(name),
+				tr::rich);
 		} else {
-			text.append(", ").append(Ui::Text::Bold(name));
+			text.append(", ").append(tr::bold(name));
 		}
 	}
 	if (remaining > 0) {
@@ -211,7 +211,7 @@ void FillUpgradeToPremiumCover(
 			remaining,
 			lt_users,
 			text,
-			Ui::Text::RichLangValue);
+			tr::rich);
 	}
 	const auto inviteOnly = !forbidden.premiumAllowsInvite.empty()
 		&& (forbidden.premiumAllowsWrite.size() != forbidden.users.size());
@@ -227,7 +227,7 @@ void FillUpgradeToPremiumCover(
 				int(userpicUsers.size()),
 				lt_users,
 				text,
-				Ui::Text::RichLangValue);
+				tr::rich);
 	container->add(
 		object_ptr<Ui::FlatLabel>(
 			container,
@@ -474,11 +474,11 @@ void InviteForbiddenController::setSimpleCover() {
 		? phraseCounted(
 			lt_count,
 			rpl::single<float64>(count),
-			Ui::Text::RichLangValue)
+			tr::rich)
 		: phraseNamed(
 			lt_user,
 			rpl::single(TextWithEntities{ _users.front()->name() }),
-			Ui::Text::RichLangValue);
+			tr::rich);
 	delegate()->peerListSetAboveWidget(object_ptr<Ui::PaddingWrap<>>(
 		(QWidget*)nullptr,
 		object_ptr<Ui::FlatLabel>(
@@ -530,18 +530,18 @@ void InviteForbiddenController::setComplexCover() {
 				? tr::lng_invite_upgrade_via_channel_about
 				: tr::lng_invite_upgrade_via_group_about)(
 					tr::now,
-					Ui::Text::WithEntities)
+					tr::marked)
 			: (_forbidden.users.size() == 1
 				? tr::lng_via_link_cant_one(
 					tr::now,
 					lt_user,
 					TextWithEntities{ _forbidden.users.front()->shortName() },
-					Ui::Text::RichLangValue)
+					tr::rich)
 				: tr::lng_via_link_cant_many(
 					tr::now,
 					lt_count,
 					int(_forbidden.users.size()),
-					Ui::Text::RichLangValue));
+					tr::rich));
 		container->add(
 			object_ptr<Ui::FlatLabel>(
 				container,
@@ -721,12 +721,12 @@ void InviteForbiddenController::send(
 				tr::now,
 				lt_user,
 				TextWithEntities{ list.front()->name() },
-				Ui::Text::RichLangValue)
+				tr::rich)
 			: tr::lng_via_link_shared_many(
 				tr::now,
 				lt_count,
 				int(list.size()),
-				Ui::Text::RichLangValue);
+				tr::rich);
 		close();
 		show->showToast(std::move(text));
 		return true;
@@ -989,14 +989,14 @@ void AddParticipantsBoxController::inviteSelectedUsers(
 				{ users.front()->name()},
 				lt_group,
 				{ _peer->name()},
-				Ui::Text::RichLangValue)
+				tr::rich)
 			: tr::lng_participant_invite_sure_many(
 				tr::now,
 				lt_count,
 				int(users.size()),
 				lt_group,
 				{ _peer->name() },
-				Ui::Text::RichLangValue);
+				tr::rich);
 		Ui::ConfirmBox(box, {
 			.text = std::move(text),
 			.confirmed = crl::guard(weak, [=](Fn<void()> &&close) {
@@ -1330,7 +1330,7 @@ void AddSpecialBoxController::loadMoreRows() {
 	const auto channel = _peer->asChannel();
 
 	_loadRequestId = _api.request(MTPchannels_GetParticipants(
-		channel->inputChannel,
+		channel->inputChannel(),
 		MTP_channelParticipantsRecent(),
 		MTP_int(_offset),
 		MTP_int(perPage),
@@ -1393,8 +1393,8 @@ bool AddSpecialBoxController::checkInfoLoaded(
 	// We don't know what this user status is in the group.
 	const auto channel = _peer->asChannel();
 	_api.request(MTPchannels_GetParticipant(
-		channel->inputChannel,
-		participant->input
+		channel->inputChannel(),
+		participant->input()
 	)).done([=](const MTPchannels_ChannelParticipant &result) {
 		result.match([&](const MTPDchannels_channelParticipant &data) {
 			channel->owner().processUsers(data.vusers());
@@ -1800,7 +1800,7 @@ void AddSpecialBoxSearchController::requestParticipants() {
 	const auto channel = _peer->asChannel();
 
 	_requestId = _api.request(MTPchannels_GetParticipants(
-		channel->inputChannel,
+		channel->inputChannel(),
 		MTP_channelParticipantsSearch(MTP_string(_query)),
 		MTP_int(_offset),
 		MTP_int(perPage),
