@@ -47,7 +47,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "lottie/lottie_single_player.h"
 #include "main/main_session.h"
 #include "settings/settings_common.h"
-#include "settings/settings_premium.h"
+#include "settings/sections/settings_premium.h"
 #include "ui/boxes/boost_box.h"
 #include "ui/chat/chat_style.h"
 #include "ui/chat/chat_theme.h"
@@ -335,8 +335,8 @@ PreviewWrap::PreviewWrap(
 
 	const auto session = &_history->session();
 	session->data().viewRepaintRequest(
-	) | rpl::on_next([=](not_null<const Element*> view) {
-		if (view == _element.get()) {
+	) | rpl::on_next([=](Data::RequestViewRepaint data) {
+		if (data.view == _element.get()) {
 			update();
 		}
 	}, lifetime());
@@ -364,6 +364,7 @@ void PreviewWrap::paintEvent(QPaintEvent *e) {
 	auto context = _theme->preparePaintContext(
 		_style.get(),
 		rect(),
+		rect(),
 		clip,
 		!window()->isActiveWindow());
 
@@ -436,7 +437,7 @@ void LevelBadge::updateText() {
 			tr::now,
 			lt_count,
 			_level,
-			Ui::Text::WithEntities));
+			tr::marked));
 	} else {
 		text.append(QString::number(_level));
 	}
@@ -602,7 +603,7 @@ void Set(
 						: Flag(0))
 					| Flag::f_background_emoji_id
 					| (values.forProfile ? Flag::f_for_profile : Flag(0))),
-				channel->inputChannel,
+				channel->inputChannel(),
 				MTP_int(values.colorIndex),
 				MTP_long(values.backgroundEmojiId)));
 		}
@@ -1095,7 +1096,12 @@ void Apply(
 	return result;
 }
 
-Fn<void()> AddColorGiftTabs(
+struct ColorGiftTabsResult {
+	Fn<void()> switchToNext;
+	QPointer<Ui::SubTabs> tabs;
+};
+
+ColorGiftTabsResult AddColorGiftTabs(
 		not_null<Ui::VerticalLayout*> container,
 		not_null<Main::Session*> session,
 		Fn<void(uint64 giftId)> chosen,
@@ -1126,7 +1132,7 @@ Fn<void()> AddColorGiftTabs(
 		auto tabs = std::vector<Ui::SubTabs::Tab>();
 		tabs.push_back({
 			.id = u"my"_q,
-			.text = tr::lng_gift_stars_tabs_my(tr::now, Ui::Text::WithEntities),
+			.text = tr::lng_gift_stars_tabs_my(tr::now, tr::marked),
 		});
 		for (const auto &gift : list) {
 			auto text = TextWithEntities();
@@ -1162,14 +1168,17 @@ Fn<void()> AddColorGiftTabs(
 		container->resizeToWidth(container->width());
 	}, container->lifetime());
 
-	return [=]() {
-		const auto &list = state->list.current();
-		if (!list.empty()) {
-			if (state->tabs) {
-				state->tabs->setActiveTab(QString::number(list.front().id));
+	return {
+		.switchToNext = [=]() {
+			const auto &list = state->list.current();
+			if (!list.empty()) {
+				if (state->tabs) {
+					state->tabs->setActiveTab(QString::number(list.front().id));
+				}
+				chosen(list.front().id);
 			}
-			chosen(list.front().id);
-		}
+		},
+		.tabs = state->tabs,
 	};
 }
 
@@ -1668,7 +1677,7 @@ void CreateBoostLevelContainer(
 						using namespace Ui::Text;
 						return Link(std::move(t), u"internal:"_q);
 					}),
-					Ui::Text::RichLangValue),
+					tr::rich),
 				style);
 			state->label->show();
 			boostLevelContainer->sizeValue(
@@ -1720,6 +1729,12 @@ void AddLevelBadge(
 	}, badge->lifetime());
 }
 
+struct ColorSectionHighlights {
+	QPointer<Ui::SettingsButton> emojiButton;
+	QPointer<Ui::SettingsButton> resetButton;
+	QPointer<Ui::SubTabs> giftTabs;
+};
+
 void EditPeerColorSection(
 		not_null<Ui::GenericBox*> box,
 		not_null<Ui::VerticalLayout*> container,
@@ -1727,7 +1742,8 @@ void EditPeerColorSection(
 		std::shared_ptr<ChatHelpers::Show> show,
 		not_null<PeerData*> peer,
 		std::shared_ptr<Ui::ChatStyle> style,
-		std::shared_ptr<Ui::ChatTheme> theme) {
+		std::shared_ptr<Ui::ChatTheme> theme,
+		ColorSectionHighlights *highlights) {
 	ProcessButton(button);
 	const auto group = peer->isMegagroup();
 
@@ -1938,7 +1954,7 @@ void EditPeerColorSection(
 		const auto iconInner = iconWrap->entity();
 
 		Ui::AddSkip(iconInner, st::settingsColorSampleSkip);
-		iconInner->add(CreateEmojiIconButton(
+		const auto emojiButton = iconInner->add(CreateEmojiIconButton(
 			iconInner,
 			show,
 			style,
@@ -1947,6 +1963,9 @@ void EditPeerColorSection(
 			state->emojiId.value(),
 			[=](DocumentId id) { state->emojiId = id; },
 			false));
+		if (highlights) {
+			highlights->emojiButton = emojiButton;
+		}
 
 		Ui::AddSkip(iconInner, st::settingsColorSampleSkip);
 		Ui::AddDividerText(
@@ -2034,11 +2053,14 @@ void EditPeerColorSection(
 		Ui::AddSkip(container, st::settingsColorSampleSkip);
 
 		const auto session = &peer->session();
-		const auto switchToNextTab = AddColorGiftTabs(
+		const auto giftTabs = AddColorGiftTabs(
 			container,
 			session,
 			[=](uint64 giftId) { state->showingGiftId = giftId; },
 			false);
+		if (highlights) {
+			highlights->giftTabs = giftTabs.tabs;
+		}
 
 		auto showingGiftId = state->showingGiftId.value();
 		AddGiftSelector(
@@ -2065,7 +2087,7 @@ void EditPeerColorSection(
 			}),
 			false,
 			rpl::single(uint64(0)),
-			switchToNextTab);
+			giftTabs.switchToNext);
 	}
 
 	button->setClickedCallback([=] {
@@ -2150,13 +2172,13 @@ void EditPeerColorSection(
 				tr::lng_gift_buy_resale_button(
 					lt_cost,
 					rpl::single(Data::FormatGiftResaleTon(*buy)),
-					Ui::Text::WithEntities),
+					tr::marked),
 				tr::lng_gift_buy_resale_equals(
 					lt_cost,
 					rpl::single(Ui::Text::IconEmoji(
 						&st::starIconEmojiSmall
 					).append(Lang::FormatCountDecimal(buy->starsForResale))),
-					Ui::Text::WithEntities),
+					tr::marked),
 				st::resaleButtonTitle,
 				st::resaleButtonSubtitle);
 		} else {
@@ -2164,7 +2186,7 @@ void EditPeerColorSection(
 				lt_cost,
 				rpl::single(Ui::Text::IconEmoji(&st::starIconEmoji).append(
 					Lang::FormatCountDecimal(buy->starsForResale))),
-				Ui::Text::WithEntities));
+				tr::marked));
 		}
 	}, button->lifetime());
 }
@@ -2177,7 +2199,8 @@ void EditPeerProfileColorSection(
 		not_null<PeerData*> peer,
 		std::shared_ptr<Ui::ChatStyle> style,
 		std::shared_ptr<Ui::ChatTheme> theme,
-		Fn<void()> aboutCallback) {
+		Fn<void()> aboutCallback,
+		ColorSectionHighlights *highlights) {
 	Expects(peer->isSelf());
 
 	ProcessButton(button);
@@ -2218,7 +2241,9 @@ void EditPeerProfileColorSection(
 			? std::nullopt
 			: std::make_optional(state->patternEmojiId.current()));
 	};
-	setIndex(peer->colorProfileIndex().value_or(kUnsetColorIndex));
+	setIndex(peer->emojiStatusId().collectible
+		? kUnsetColorIndex
+		: peer->colorProfileIndex().value_or(kUnsetColorIndex));
 
 	const auto margin = st::settingsColorRadioMargin;
 	const auto skip = st::settingsColorRadioSkip;
@@ -2235,7 +2260,7 @@ void EditPeerProfileColorSection(
 		{ margin, skip, margin, skip });
 
 	Ui::AddSkip(container, st::settingsColorSampleSkip);
-	container->add(CreateEmojiIconButton(
+	const auto emojiButton = container->add(CreateEmojiIconButton(
 		container,
 		show,
 		style,
@@ -2248,6 +2273,9 @@ void EditPeerProfileColorSection(
 			resetUnique();
 		},
 		true));
+	if (highlights) {
+		highlights->emojiButton = emojiButton;
+	}
 
 	const auto resetWrap = container->add(
 		object_ptr<Ui::SlideWrap<Ui::VerticalLayout>>(
@@ -2261,6 +2289,9 @@ void EditPeerProfileColorSection(
 			resetInner,
 			tr::lng_settings_color_reset(),
 			st::settingsButtonLightNoIcon));
+	if (highlights) {
+		highlights->resetButton = resetButton;
+	}
 	resetButton->setClickedCallback([=] {
 		state->index = kUnsetColorIndex;
 		state->patternEmojiId = 0;
@@ -2282,11 +2313,11 @@ void EditPeerProfileColorSection(
 			tr::lng_settings_color_profile_about_link(
 				lt_emoji,
 				rpl::single(Ui::Text::IconEmoji(&st::textMoreIconEmoji)),
-				Ui::Text::RichLangValue
+				tr::rich
 			) | rpl::map([=](TextWithEntities t) {
-				return Ui::Text::Link(std::move(t), u"internal:"_q);
+				return tr::link(std::move(t), u"internal:"_q);
 			}),
-			Ui::Text::RichLangValue));
+			tr::rich));
 	Ui::AddSkip(container, st::settingsColorSampleSkip);
 	about->setClickHandlerFilter([=](auto...) {
 		aboutCallback();
@@ -2304,11 +2335,14 @@ void EditPeerProfileColorSection(
 		Ui::AddSkip(container, st::settingsColorSampleSkip);
 
 		const auto session = &peer->session();
-		const auto switchToNextTab = AddColorGiftTabs(
+		const auto giftTabs = AddColorGiftTabs(
 			container,
 			session,
 			[=](uint64 giftId) { state->showingGiftId = giftId; },
 			true);
+		if (highlights) {
+			highlights->giftTabs = giftTabs.tabs;
+		}
 
 		auto showingGiftId = state->showingGiftId.value();
 		AddGiftSelector(
@@ -2336,7 +2370,7 @@ void EditPeerProfileColorSection(
 			}),
 			true,
 			state->selectedGiftId.value(),
-			switchToNextTab);
+			giftTabs.switchToNext);
 	}
 
 	struct ProfileState {
@@ -2412,13 +2446,13 @@ void EditPeerProfileColorSection(
 				tr::lng_gift_buy_resale_button(
 					lt_cost,
 					rpl::single(Data::FormatGiftResaleTon(*buy)),
-					Ui::Text::WithEntities),
+					tr::marked),
 				tr::lng_gift_buy_resale_equals(
 					lt_cost,
 					rpl::single(Ui::Text::IconEmoji(
 						&st::starIconEmojiSmall
 					).append(Lang::FormatCountDecimal(buy->starsForResale))),
-					Ui::Text::WithEntities),
+					tr::marked),
 				st::resaleButtonTitle,
 				st::resaleButtonSubtitle);
 		} else {
@@ -2426,17 +2460,28 @@ void EditPeerProfileColorSection(
 				lt_cost,
 				rpl::single(Ui::Text::IconEmoji(&st::starIconEmoji).append(
 					Lang::FormatCountDecimal(buy->starsForResale))),
-				Ui::Text::WithEntities));
+				tr::marked));
 		}
 	}, button->lifetime());
 }
 
 void EditPeerColorBox(
 		not_null<Ui::GenericBox*> box,
-		std::shared_ptr<ChatHelpers::Show> show,
+		not_null<Window::SessionController*> controller,
 		not_null<PeerData*> peer,
 		std::shared_ptr<Ui::ChatStyle> style,
-		std::shared_ptr<Ui::ChatTheme> theme) {
+		std::shared_ptr<Ui::ChatTheme> theme,
+		PeerColorTab initialTab) {
+	const auto show = controller->uiShow();
+	if (!style) {
+		style = std::make_shared<Ui::ChatStyle>(
+			peer->session().colorIndicesValue());
+	}
+	if (!theme) {
+		theme = std::shared_ptr<Ui::ChatTheme>(
+			Window::Theme::DefaultChatThemeOn(box->lifetime()));
+		style->apply(theme.get());
+	}
 	box->setTitle(peer->isSelf()
 		? tr::lng_settings_color_title()
 		: tr::lng_edit_channel_color());
@@ -2449,7 +2494,7 @@ void EditPeerColorBox(
 		const auto button = box->addButton(
 			tr::lng_settings_color_apply(),
 			[] {});
-		EditPeerColorSection(box, box->verticalLayout(), button, show, peer, style, theme);
+		EditPeerColorSection(box, box->verticalLayout(), button, show, peer, style, theme, nullptr);
 		return;
 	}
 	const auto buttonContainer = box->addButton(
@@ -2515,6 +2560,12 @@ void EditPeerColorBox(
 	content->add(std::move(profileOwned));
 	content->add(std::move(nameOwned));
 
+	struct HighlightState {
+		ColorSectionHighlights profile;
+		ColorSectionHighlights name;
+	};
+	const auto highlightState = box->lifetime().make_state<HighlightState>();
+
 	EditPeerProfileColorSection(
 		box,
 		profile,
@@ -2523,9 +2574,38 @@ void EditPeerColorBox(
 		peer,
 		style,
 		theme,
-		[=] { switchTab(1); });
+		[=] { switchTab(1); },
+		&highlightState->profile);
 
-	EditPeerColorSection(box, name, nameButton, show, peer, style, theme);
+	EditPeerColorSection(
+		box,
+		name,
+		nameButton,
+		show,
+		peer,
+		style,
+		theme,
+		&highlightState->name);
+
+	if (initialTab == PeerColorTab::Name) {
+		switchTab(1);
+	}
+
+	box->setShowFinishedCallback([=] {
+		const auto isProfileTab = (initialTab == PeerColorTab::Profile);
+		const auto &highlights = isProfileTab
+			? highlightState->profile
+			: highlightState->name;
+		controller->checkHighlightControl(
+			u"profile-color/add-icons"_q,
+			highlights.emojiButton.data());
+		controller->checkHighlightControl(
+			u"profile-color/use-gift"_q,
+			highlights.giftTabs.data());
+		controller->checkHighlightControl(
+			u"profile-color/reset"_q,
+			highlights.resetButton.data());
+	});
 }
 
 void SetupPeerColorSample(
@@ -2715,7 +2795,7 @@ void SetupPeerColorSample(
 	emojiStatusWidget->setAttribute(Qt::WA_TransparentForMouseEvents);
 }
 
-void AddPeerColorButton(
+not_null<Ui::SettingsButton*> AddPeerColorButton(
 		not_null<Ui::VerticalLayout*> container,
 		std::shared_ptr<ChatHelpers::Show> show,
 		not_null<PeerData*> peer,
@@ -2766,8 +2846,17 @@ void AddPeerColorButton(
 	}
 
 	button->setClickedCallback([=] {
-		show->show(Box(EditPeerColorBox, show, peer, style, theme));
+		if (const auto controller = show->resolveWindow()) {
+			controller->show(Box(
+				EditPeerColorBox,
+				controller,
+				peer,
+				style,
+				theme,
+				PeerColorTab::Profile));
+		}
 	});
+	return button;
 }
 
 void CheckBoostLevel(
@@ -2776,7 +2865,7 @@ void CheckBoostLevel(
 		Fn<std::optional<Ui::AskBoostReason>(int level)> askMore,
 		Fn<void()> cancel) {
 	peer->session().api().request(MTPpremium_GetBoostsStatus(
-		peer->input
+		peer->input()
 	)).done([=](const MTPpremium_BoostsStatus &result) {
 		const auto &data = result.data();
 		if (const auto channel = peer->asChannel()) {
