@@ -22,6 +22,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "main/main_domain.h" // kMaxAccounts
 #include "ui/chat/chat_theme.h"
 #include "ui/chat/chat_style.h"
+#include "ui/controls/feature_list.h"
 #include "ui/layers/generic_box.h"
 #include "ui/effects/path_shift_gradient.h"
 #include "ui/effects/premium_graphics.h"
@@ -34,8 +35,8 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "ui/boxes/confirm_box.h"
 #include "ui/painter.h"
 #include "ui/vertical_list.h"
-#include "settings/settings_business.h"
-#include "settings/settings_premium.h"
+#include "settings/sections/settings_business.h"
+#include "settings/sections/settings_premium.h"
 #include "lottie/lottie_single_player.h"
 #include "history/view/media/history_view_sticker.h"
 #include "history/view/history_view_element.h"
@@ -904,42 +905,28 @@ struct VideoPreviewDocument {
 }
 
 void AddGiftsInfoRows(not_null<Ui::VerticalLayout*> container) {
-	const auto infoRow = [&](
-			rpl::producer<QString> title,
-			rpl::producer<QString> text,
-			not_null<const style::icon*> icon) {
-		auto raw = container->add(
-			object_ptr<Ui::VerticalLayout>(container));
-		raw->add(
-			object_ptr<Ui::FlatLabel>(
-				raw,
-				std::move(title) | Ui::Text::ToBold(),
-				st::defaultFlatLabel),
-			st::settingsPremiumRowTitlePadding);
-		raw->add(
-			object_ptr<Ui::FlatLabel>(
-				raw,
-				std::move(text),
-				st::upgradeGiftSubtext),
-			st::settingsPremiumRowAboutPadding);
-		object_ptr<Info::Profile::FloatingIcon>(
-			raw,
-			*icon,
-			st::starrefInfoIconPosition);
+	const auto features = std::vector<Ui::FeatureListEntry>{
+		{
+			st::menuIconUnique,
+			tr::lng_gift_upgrade_unique_title(tr::now),
+			tr::lng_gift_upgrade_unique_about(tr::now, tr::marked),
+		},
+		{
+			st::menuIconTradable,
+			tr::lng_gift_upgrade_tradable_title(tr::now),
+			tr::lng_gift_upgrade_tradable_about(tr::now, tr::marked),
+		},
+		{
+			st::menuIconNftWear,
+			tr::lng_gift_upgrade_wearable_title(tr::now),
+			tr::lng_gift_upgrade_wearable_about(tr::now, tr::marked),
+		},
 	};
-
-	infoRow(
-		tr::lng_gift_upgrade_unique_title(),
-		tr::lng_gift_upgrade_unique_about(),
-		&st::menuIconUnique);
-	infoRow(
-		tr::lng_gift_upgrade_tradable_title(),
-		tr::lng_gift_upgrade_tradable_about(),
-		&st::menuIconTradable);
-	infoRow(
-		tr::lng_gift_upgrade_wearable_title(),
-		tr::lng_gift_upgrade_wearable_about(),
-		&st::menuIconNftWear);
+	for (const auto &feature : features) {
+		container->add(
+			Ui::MakeFeatureListEntry(container, feature),
+			st::boxRowPadding);
+	}
 }
 
 void PreviewBox(
@@ -1473,7 +1460,7 @@ void PremiumUnavailableBox(not_null<Ui::GenericBox*> box) {
 	Ui::ConfirmBox(box, {
 		.text = tr::lng_premium_unavailable(
 			tr::now,
-			Ui::Text::RichLangValue),
+			tr::rich),
 		.inform = true,
 	});
 }
@@ -1492,7 +1479,7 @@ void DoubledLimitsPreviewBox(
 			tr::lng_premium_double_limits_about_channels(
 				lt_count,
 				rpl::single(float64(premium)),
-				Ui::Text::RichLangValue),
+				tr::rich),
 			limits.channelsDefault(),
 			premium,
 		});
@@ -1504,7 +1491,7 @@ void DoubledLimitsPreviewBox(
 			tr::lng_premium_double_limits_about_pins(
 				lt_count,
 				rpl::single(float64(premium)),
-				Ui::Text::RichLangValue),
+				tr::rich),
 			limits.dialogsPinnedDefault(),
 			premium,
 		});
@@ -1516,7 +1503,7 @@ void DoubledLimitsPreviewBox(
 			tr::lng_premium_double_limits_about_links(
 				lt_count,
 				rpl::single(float64(premium)),
-				Ui::Text::RichLangValue),
+				tr::rich),
 			limits.channelsPublicDefault(),
 			premium,
 		});
@@ -1528,7 +1515,7 @@ void DoubledLimitsPreviewBox(
 			tr::lng_premium_double_limits_about_gifs(
 				lt_count,
 				rpl::single(float64(premium)),
-				Ui::Text::RichLangValue),
+				tr::rich),
 			limits.gifsDefault(),
 			premium,
 		});
@@ -1540,7 +1527,7 @@ void DoubledLimitsPreviewBox(
 			tr::lng_premium_double_limits_about_stickers(
 				lt_count,
 				rpl::single(float64(premium)),
-				Ui::Text::RichLangValue),
+				tr::rich),
 			limits.stickersFavedDefault(),
 			premium,
 		});
@@ -1550,7 +1537,7 @@ void DoubledLimitsPreviewBox(
 		entries.push_back({
 			tr::lng_premium_double_limits_subtitle_bio(),
 			tr::lng_premium_double_limits_about_bio(
-				Ui::Text::RichLangValue),
+				tr::rich),
 			limits.aboutLengthDefault(),
 			premium,
 		});
@@ -1560,7 +1547,7 @@ void DoubledLimitsPreviewBox(
 		entries.push_back({
 			tr::lng_premium_double_limits_subtitle_captions(),
 			tr::lng_premium_double_limits_about_captions(
-				Ui::Text::RichLangValue),
+				tr::rich),
 			limits.captionLengthDefault(),
 			premium,
 		});
@@ -1572,7 +1559,7 @@ void DoubledLimitsPreviewBox(
 			tr::lng_premium_double_limits_about_folders(
 				lt_count,
 				rpl::single(float64(premium)),
-				Ui::Text::RichLangValue),
+				tr::rich),
 			limits.dialogFiltersDefault(),
 			premium,
 		});
@@ -1584,7 +1571,7 @@ void DoubledLimitsPreviewBox(
 			tr::lng_premium_double_limits_about_folder_chats(
 				lt_count,
 				rpl::single(float64(premium)),
-				Ui::Text::RichLangValue),
+				tr::rich),
 			limits.dialogFiltersChatsDefault(),
 			premium,
 		});
@@ -1598,7 +1585,7 @@ void DoubledLimitsPreviewBox(
 		tr::lng_premium_double_limits_about_accounts(
 			lt_count,
 			rpl::single(float64(Main::Domain::kPremiumMaxAccounts)),
-			Ui::Text::RichLangValue),
+			tr::rich),
 		Main::Domain::kMaxAccounts,
 		Main::Domain::kPremiumMaxAccounts,
 		till,
@@ -1610,7 +1597,7 @@ void DoubledLimitsPreviewBox(
 			tr::lng_premium_double_limits_about_similar_channels(
 				lt_count,
 				rpl::single(float64(premium)),
-				Ui::Text::RichLangValue),
+				tr::rich),
 			limits.similarChannelsDefault(),
 			premium,
 		});
