@@ -21,6 +21,11 @@ namespace Payments {
 struct CreditsFormData;
 } // namespace Payments
 
+namespace Settings {
+enum class SmallBalanceResult;
+struct SmallBalanceSource;
+} // namespace Settings
+
 namespace Ui {
 
 class RpWidget;
@@ -30,13 +35,11 @@ class FlatLabel;
 void SendCreditsBox(
 	not_null<Ui::GenericBox*> box,
 	std::shared_ptr<Payments::CreditsFormData> data,
-	Fn<void()> sent);
+	Fn<void(Settings::SmallBalanceResult)> sent);
 
-[[nodiscard]] TextWithEntities CreditsEmoji(
-	not_null<Main::Session*> session);
+[[nodiscard]] TextWithEntities CreditsEmoji();
 
-[[nodiscard]] TextWithEntities CreditsEmojiSmall(
-	not_null<Main::Session*> session);
+[[nodiscard]] TextWithEntities CreditsEmojiSmall();
 
 not_null<FlatLabel*> SetButtonMarkedLabel(
 	not_null<RpWidget*> button,
@@ -57,4 +60,7 @@ void SendStarsForm(
 	std::shared_ptr<Payments::CreditsFormData> data,
 	Fn<void(std::optional<QString>)> done);
 
+[[nodiscard]] Settings::SmallBalanceSource SmallBalanceSourceFromForm(
+	std::shared_ptr<Payments::CreditsFormData> form);
+
 } // namespace Ui
