@@ -40,6 +40,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "settings/settings_credits_graphics.h"
 #include "storage/storage_account.h"
 #include "ui/boxes/confirm_box.h"
+#include "ui/boxes/emoji_stake_box.h" // AddStarsInputField
 #include "ui/controls/button_labels.h"
 #include "ui/controls/feature_list.h"
 #include "ui/controls/table_rows.h"
@@ -352,7 +353,7 @@ void PlaceAuctionBid(
 			| (passDetails ? Flag::f_peer : Flag())
 			| (passDetails ? Flag::f_message : Flag())
 			| (hideName ? Flag::f_hide_name : Flag())),
-		passDetails ? to->input : MTP_inputPeerEmpty(),
+		passDetails ? to->input() : MTP_inputPeerEmpty(),
 		MTP_long(state.gift->id),
 		MTP_long(amount),
 		MTP_textWithEntities(
@@ -603,7 +604,7 @@ void EditCustomBid(
 
 	box->addTopButton(st::boxTitleClose, [=] { box->closeBox(); });
 
-	const auto starsField = HistoryView::AddStarsInputField(container, {
+	const auto starsField = AddStarsInputField(container, {
 		.value = current,
 	});
 
@@ -951,31 +952,7 @@ void AuctionBidBox(not_null<GenericBox*> box, AuctionBidBoxArgs &&args) {
 			lt_gift,
 			tr::bold(name),
 			tr::marked),
-		helper.context());
-}
-
-[[nodiscard]] std::vector<int> RandomIndicesSubset(int total, int subset) {
-	const auto take = std::min(total, subset);
-	if (!take) {
-		return {};
-	}
-	auto result = std::vector<int>();
-	auto taken = base::flat_set<int>();
-	result.reserve(take);
-	taken.reserve(take);
-	for (auto i = 0; i < take; ++i) {
-		auto index = base::RandomIndex(total - i);
-		for (const auto already : taken) {
-			if (index >= already) {
-				++index;
-			} else {
-				break;
-			}
-		}
-		taken.emplace(index);
-		result.push_back(index);
-	}
-	return result;
+		helper.context()).widget;
 }
 
 [[nodiscard]] object_ptr<TableLayout> AuctionInfoTable(
@@ -1216,7 +1193,7 @@ void AuctionGotGiftsBox(
 		).append(' ').append(
 			helper.paletteDependent(
 				Text::CustomEmojiTextBadge(
-					'#' + QString::number(entry.position),
+					'#' + Lang::FormatCountDecimal(entry.position),
 					st::defaultTableSmallButton)));
 		AddTableRow(
 			table,
@@ -1327,7 +1304,7 @@ void AuctionInfoBox(
 
 	struct State {
 		explicit State(not_null<Main::Session*> session)
-			: delegate(session, GiftButtonMode::Minimal) {
+		: delegate(session, GiftButtonMode::Minimal) {
 		}
 
 		Delegate delegate;
@@ -1381,7 +1358,7 @@ void AuctionInfoBox(
 	});
 	AddSkip(container, st::defaultVerticalListSkip * 2);
 
-	AddUniqueCloseButton(
+	Settings::AddUniqueCloseMoreButton(
 		box,
 		{},
 		now.finished() ? nullptr : MakeAuctionFillMenuCallback(show, now));
@@ -1469,7 +1446,10 @@ void AuctionInfoBox(
 				st::boxRowPadding + st::uniqueGiftValueAvailableMargin,
 				style::al_top
 			)->setClickHandlerFilter([=](const auto &...) {
-				show->show(Box(StarGiftPreviewBox, window, *now.gift, list));
+				const auto title = now.gift->resellTitle;
+				const auto type = Data::GiftAttributeIdType::Model;
+				const auto null = nullptr;
+				show->show(Box(StarGiftPreviewBox, title, list, type, null));
 				return false;
 			});
 		}, box->lifetime());
@@ -1603,7 +1583,7 @@ base::weak_qptr<BoxContent> ChooseAndShowAuctionBox(
 rpl::lifetime ShowStarGiftAuction(
 		not_null<Window::SessionController*> controller,
 		PeerData *peer,
-		QString slug,
+		uint64 giftId,
 		Fn<void()> finishRequesting,
 		Fn<void()> boxClosed) {
 	const auto weak = base::make_weak(controller);
@@ -1614,7 +1594,7 @@ rpl::lifetime ShowStarGiftAuction(
 	};
 	const auto state = std::make_shared<State>();
 	auto result = session->giftAuctions().state(
-		slug
+		giftId
 	) | rpl::on_next([=](Data::GiftAuctionState &&value) {
 		if (const auto onstack = finishRequesting) {
 			onstack();
@@ -1908,7 +1888,7 @@ rpl::producer<TextWithEntities> ActiveAuctionsButton(
 }
 
 struct Single {
-	QString slug;
+	uint64 giftId = 0;
 	not_null<DocumentData*> document;
 	int round = 0;
 	int total = 0;
@@ -1922,7 +1902,7 @@ object_ptr<Ui::RpWidget> MakeActiveAuctionRow(
 		not_null<QWidget*> parent,
 		not_null<Window::SessionController*> window,
 		not_null<DocumentData*> document,
-		const QString &slug,
+		uint64 giftId,
 		rpl::producer<Single> value) {
 	auto result = object_ptr<Ui::VerticalLayout>(parent);
 	const auto raw = result.data();
@@ -2019,7 +1999,7 @@ object_ptr<Ui::RpWidget> MakeActiveAuctionRow(
 			Ui::Text::Colorized(NiceCountdownText(seconds)));
 	}));
 	button->setClickedCallback([=] {
-		window->showStarGiftAuction(slug);
+		window->showStarGiftAuction(giftId);
 	});
 	button->setFullRadius(true);
 	raw->widthValue() | rpl::on_next([=](int width) {
@@ -2035,9 +2015,9 @@ Fn<void()> ActiveAuctionsCallback(
 	const auto &list = auctions.list;
 	const auto count = int(list.size());
 	if (count == 1) {
-		const auto slug = list.front()->gift->auctionSlug;
+		const auto giftId = list.front()->gift->id;
 		return [=] {
-			window->showStarGiftAuction(slug);
+			window->showStarGiftAuction(giftId);
 		};
 	}
 	struct Auctions {
@@ -2046,7 +2026,7 @@ Fn<void()> ActiveAuctionsCallback(
 	const auto state = std::make_shared<Auctions>();
 	const auto singleFrom = [](const Data::GiftAuctionState &state) {
 		return Single{
-			.slug = state.gift->auctionSlug,
+			.giftId = state.gift->id,
 			.document = state.gift->document,
 			.round = state.currentRound,
 			.total = state.totalRounds,
@@ -2076,7 +2056,7 @@ Fn<void()> ActiveAuctionsCallback(
 
 				const auto &now = entry.current();
 				entry = auctions->state(
-					now.slug
+					now.giftId
 				) | rpl::filter([=](const GiftAuctionState &state) {
 					return state.my.bid != 0;
 				}) | rpl::map(singleFrom);
@@ -2087,12 +2067,12 @@ Fn<void()> ActiveAuctionsCallback(
 						box,
 						window,
 						now.document,
-						now.slug,
+						now.giftId,
 						entry.value()),
 					st::boxRowPadding + QMargins(0, skip, 0, skip));
 
 				auctions->state(
-					now.slug
+					now.giftId
 				) | rpl::on_next([=](const GiftAuctionState &state) {
 					if (!state.my.bid) {
 						delete row;
@@ -2111,4 +2091,28 @@ Fn<void()> ActiveAuctionsCallback(
 	};
 }
 
+std::vector<int> RandomIndicesSubset(int total, int subset) {
+	const auto take = std::min(total, subset);
+	if (!take) {
+		return {};
+	}
+	auto result = std::vector<int>();
+	auto taken = base::flat_set<int>();
+	result.reserve(take);
+	taken.reserve(take);
+	for (auto i = 0; i < take; ++i) {
+		auto index = base::RandomIndex(total - i);
+		for (const auto already : taken) {
+			if (index >= already) {
+				++index;
+			} else {
+				break;
+			}
+		}
+		taken.emplace(index);
+		result.push_back(index);
+	}
+	return result;
+}
+
 } // namespace Ui
