@@ -7,8 +7,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 */
 #include "core/local_url_handlers.h"
 
-#include "api/api_authorizations.h"
-#include "api/api_cloud_password.h"
+#include "core/deep_links/deep_links_router.h"
 #include "api/api_confirm_phone.h"
 #include "api/api_chat_filters.h"
 #include "api/api_chat_invite.h"
@@ -35,6 +34,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "boxes/sticker_set_box.h"
 #include "boxes/star_gift_box.h"
 #include "boxes/language_box.h"
+#include "boxes/url_auth_box.h"
 #include "passport/passport_form_controller.h"
 #include "ui/text/text_utilities.h"
 #include "ui/toast/toast.h"
@@ -53,18 +53,10 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "window/window_peer_menu.h"
 #include "window/themes/window_theme_editor_box.h" // GenerateSlug.
 #include "payments/payments_checkout_process.h"
-#include "settings/cloud_password/settings_cloud_password_login_email.h"
-#include "settings/settings_active_sessions.h"
-#include "settings/settings_credits.h"
+#include "settings/sections/settings_credits.h"
 #include "settings/settings_credits_graphics.h"
-#include "settings/settings_information.h"
-#include "settings/settings_global_ttl.h"
-#include "settings/settings_folders.h"
-#include "settings/settings_main.h"
 #include "settings/settings_privacy_controllers.h"
-#include "settings/settings_privacy_security.h"
-#include "settings/settings_chat.h"
-#include "settings/settings_premium.h"
+#include "settings/sections/settings_premium.h"
 #include "storage/storage_account.h"
 #include "mainwidget.h"
 #include "main/main_account.h"
@@ -154,10 +146,10 @@ void PersonalChannelController::prepare() {
 		}
 		if (!delegate()->peerListFullRowsCount()) {
 			auto none = rpl::combine(
-				tr::lng_settings_channel_no_yet(Ui::Text::WithEntities),
+				tr::lng_settings_channel_no_yet(tr::marked),
 				tr::lng_settings_channel_start()
 			) | rpl::map([](TextWithEntities &&text, const QString &link) {
-				return text.append('\n').append(Ui::Text::Link(link));
+				return text.append('\n').append(tr::link(link));
 			});
 			auto label = object_ptr<Ui::FlatLabel>(
 				nullptr,
@@ -231,7 +223,7 @@ void SavePersonalChannel(
 			&& self->personalChannelMessageId() != messageId)) {
 		self->setPersonalChannel(channelId, messageId);
 		self->session().api().request(MTPaccount_UpdatePersonalChannel(
-			channel ? channel->inputChannel : MTP_inputChannelEmpty()
+			channel ? channel->inputChannel() : MTP_inputChannelEmpty()
 		)).done(crl::guard(window, [=] {
 			window->showToast((channel
 				? tr::lng_settings_channel_saved
@@ -306,42 +298,6 @@ void ShowLanguagesBox(Window::SessionController *controller) {
 	Guard = LanguageBox::Show(controller);
 }
 
-void ShowPhonePrivacyBox(Window::SessionController *controller) {
-	static auto Guard = base::binary_guard();
-	auto guard = base::binary_guard();
-
-	using Privacy = Api::UserPrivacy;
-	const auto key = Privacy::Key::PhoneNumber;
-	controller->session().api().userPrivacy().reload(key);
-
-	const auto weak = base::make_weak(controller);
-	auto shared = std::make_shared<base::binary_guard>(
-		guard.make_guard());
-	auto lifetime = std::make_shared<rpl::lifetime>();
-	controller->session().api().userPrivacy().value(
-		key
-	) | rpl::take(
-		1
-	) | rpl::on_next([=](const Privacy::Rule &value) mutable {
-		using namespace ::Settings;
-		const auto show = shared->alive();
-		if (lifetime) {
-			base::take(lifetime)->destroy();
-		}
-		if (show) {
-			if (const auto controller = weak.get()) {
-				controller->show(Box<EditPrivacyBox>(
-					controller,
-					std::make_unique<PhoneNumberPrivacyController>(
-						controller),
-					value));
-			}
-		}
-	}, *lifetime);
-
-	Guard = std::move(guard);
-}
-
 bool SetLanguage(
 		Window::SessionController *controller,
 		const Match &match,
@@ -499,33 +455,6 @@ bool ShowWallPaper(
 	return result;
 }
 
-void LoginEmailBox(
-		not_null<Ui::GenericBox*> box,
-		rpl::producer<QString> email,
-		Fn<void()> callback) {
-	{
-		box->getDelegate()->setTitle(rpl::duplicate(
-			email
-		) | rpl::map(Ui::Text::WrapEmailPattern));
-		for (const auto &child : ranges::views::reverse(
-				box->parentWidget()->children())) {
-			if (child && child->isWidgetType()) {
-				(static_cast<QWidget*>(child))->setAttribute(
-					Qt::WA_TransparentForMouseEvents);
-				break;
-			}
-		}
-	}
-	Ui::ConfirmBox(box, Ui::ConfirmBoxArgs{
-		.text = tr::lng_settings_cloud_login_email_box_about(),
-		.confirmed = [=](Fn<void()> close) {
-			callback();
-			close();
-		},
-		.confirmText = tr::lng_settings_cloud_login_email_box_ok(),
-	});
-}
-
 [[nodiscard]] ChatAdminRights ParseRequestedAdminRights(
 		const QString &value) {
 	auto result = ChatAdminRights();
@@ -604,6 +533,17 @@ bool ResolveUsernameOrPhone(
 		ResolveGiftCode(controller, appnameParam, fromId, toId);
 		return true;
 	}
+	if (domainParam == u"oauth"_q) {
+		const auto token = params.value(u"startapp"_q);
+		if (!token.isEmpty()) {
+			UrlAuthBox::ActivateUrl(
+				controller->uiShow(),
+				&controller->session(),
+				u"tg://resolve?domain=oauth&startapp="_q + token,
+				context);
+			return true;
+		}
+	}
 
 	// Fix t.me/s/username links.
 	const auto webChannelPreviewLink = (domainParam == u"s"_q)
@@ -787,68 +727,6 @@ bool ResolvePrivatePost(
 	return true;
 }
 
-void ShowLoginEmailSettings(Window::SessionController *controller) {
-	controller->session().api().cloudPassword().reload();
-	controller->uiShow()->show(Box(
-		LoginEmailBox,
-		controller->session().api().cloudPassword().state(
-		) | rpl::map([](const Core::CloudPasswordState &state) {
-			return state.loginEmailPattern;
-		}),
-		[=] {
-			controller->showSettings(
-				::Settings::CloudLoginEmailId());
-			controller->window().activate();
-		}));
-}
-
-bool ResolveSettings(
-		Window::SessionController *controller,
-		const Match &match,
-		const QVariant &context) {
-	const auto section = match->captured(1).mid(1).toLower();
-	const auto type = [&]() -> std::optional<::Settings::Type> {
-		if (section == u"language"_q) {
-			ShowLanguagesBox(controller);
-			return {};
-		} else if (section == u"phone_privacy"_q) {
-			ShowPhonePrivacyBox(controller);
-			return {};
-		} else if (section == u"devices"_q) {
-			return ::Settings::Sessions::Id();
-		} else if (section == u"folders"_q) {
-			return ::Settings::Folders::Id();
-		} else if (section == u"privacy"_q) {
-			return ::Settings::PrivacySecurity::Id();
-		} else if (section == u"themes"_q) {
-			return ::Settings::Chat::Id();
-		} else if (section == u"change_number"_q) {
-			controller->show(
-				Ui::MakeInformBox(tr::lng_change_phone_error()));
-			return {};
-		} else if (section == u"auto_delete"_q) {
-			return ::Settings::GlobalTTLId();
-		} else if (section == u"information"_q) {
-			return ::Settings::Information::Id();
-		} else if (section == u"login_email"_q) {
-			ShowLoginEmailSettings(controller);
-			return {};
-		}
-		return ::Settings::Main::Id();
-	}();
-
-	if (type.has_value()) {
-		if (!controller) {
-			return false;
-		} else if (*type == ::Settings::Sessions::Id()) {
-			controller->session().api().authorizations().reload();
-		}
-		controller->showSettings(*type);
-		controller->window().activate();
-	}
-	return true;
-}
-
 bool HandleUnknown(
 		Window::SessionController *controller,
 		const Match &match,
@@ -993,7 +871,7 @@ bool ShowEditBirthday(
 		const auto save = [=](Data::Birthday result) {
 			using BFlag = MTPDbirthday::Flag;
 			controller->session().api().request(MTPusers_SuggestBirthday(
-				targetUser->inputUser,
+				targetUser->inputUser(),
 				MTP_birthday(
 					MTP_flags(result.year() ? BFlag::f_year : BFlag()),
 					MTP_int(result.day()),
@@ -1085,14 +963,12 @@ bool ShowEditBirthday(
 				std::move(isExactlyContacts),
 				tr::lng_settings_birthday_contacts(
 					lt_link,
-					tr::lng_settings_birthday_contacts_link(
-					) | Ui::Text::ToLink(link),
-					Ui::Text::WithEntities),
+					tr::lng_settings_birthday_contacts_link(tr::url(link)),
+					tr::marked),
 				tr::lng_settings_birthday_about(
 					lt_link,
-					tr::lng_settings_birthday_about_link(
-					) | Ui::Text::ToLink(link),
-					Ui::Text::WithEntities)));
+					tr::lng_settings_birthday_about_link(tr::url(link)),
+					tr::marked)));
 		}));
 
 	}
@@ -1146,6 +1022,22 @@ bool ShowEditPersonalChannel(
 	} else if (controller->showFrozenError()) {
 		return true;
 	}
+	const auto maybePeerId = match->captured(1);
+	const auto maybeRemove = match->captured(2);
+
+	if (!maybePeerId.isEmpty()) {
+		if (const auto peerId = PeerId(maybePeerId.toULongLong())) {
+			if (const auto peer = controller->session().data().peer(peerId)) {
+				if (const auto channel = peer->asChannel()) {
+					SavePersonalChannel(controller, channel);
+					return true;
+				}
+			}
+		}
+	} else if (!maybeRemove.isEmpty()) {
+		SavePersonalChannel(controller, nullptr);
+		return true;
+	}
 
 	auto listController = std::make_unique<PersonalChannelController>(
 		controller);
@@ -1258,7 +1150,7 @@ bool EditPaidMessagesFee(
 			ShowEditChatPermissions(controller, channel);
 		}
 	} else {
-		controller->show(Box(EditMessagesPrivacyBox, controller));
+		controller->show(Box(EditMessagesPrivacyBox, controller, QString()));
 	}
 	return true;
 }
@@ -1581,10 +1473,10 @@ bool ResolveTopUp(
 					.text = tr::lng_credits_enough(
 						tr::now,
 						lt_link,
-						Ui::Text::Link(
-							Ui::Text::Bold(
+						tr::link(
+							tr::bold(
 								tr::lng_credits_enough_link(tr::now))),
-						Ui::Text::RichLangValue),
+						tr::rich),
 					.filter = filter,
 					.duration = 4 * crl::time(1000),
 				});
@@ -1689,8 +1581,36 @@ bool ResolveTonSettings(
 	return true;
 }
 
+bool ResolveOAuth(
+		Window::SessionController *controller,
+		const Match &match,
+		const QVariant &context) {
+	if (!controller) {
+		return false;
+	}
+	const auto params = url_parse_params(
+		match->captured(1),
+		qthelp::UrlParamNameTransform::ToLower);
+	const auto token = params.value(u"token"_q);
+	if (token.isEmpty()) {
+		return false;
+	}
+	UrlAuthBox::ActivateUrl(
+		controller->uiShow(),
+		&controller->session(),
+		u"tg://oauth?token="_q + token,
+		context);
+	return true;
+}
+
 } // namespace
 
+bool TryRouterForLocalUrl(
+		Window::SessionController *controller,
+		const QString &command) {
+	return DeepLinks::Router::Instance().tryHandle(controller, command);
+}
+
 const std::vector<LocalUrlHandler> &LocalUrlHandlers() {
 	static auto Result = std::vector<LocalUrlHandler>{
 		{
@@ -1745,10 +1665,6 @@ const std::vector<LocalUrlHandler> &LocalUrlHandlers() {
 			u"^privatepost/?\\?(.+)(#|$)"_q,
 			ResolvePrivatePost
 		},
-		{
-			u"^settings(/language|/devices|/folders|/privacy|/themes|/change_number|/auto_delete|/information|/edit_profile|/phone_privacy|/login_email)?$"_q,
-			ResolveSettings
-		},
 		{
 			u"^test_chat_theme/?\\?(.+)(#|$)"_q,
 			ResolveTestChatTheme,
@@ -1801,6 +1717,10 @@ const std::vector<LocalUrlHandler> &LocalUrlHandlers() {
 			u"^ton/?(^\\?.*)?(#|$)"_q,
 			ResolveTonSettings
 		},
+		{
+			u"^oauth/?\\?(.+)(#|$)"_q,
+			ResolveOAuth
+		},
 		{
 			u"^([^\\?]+)(\\?|#|$)"_q,
 			HandleUnknown
@@ -1840,7 +1760,7 @@ const std::vector<LocalUrlHandler> &InternalUrlHandlers() {
 			ShowEditBirthdayPrivacy,
 		},
 		{
-			u"^edit_personal_channel$"_q,
+			u"^edit_personal_channel(?::(?:(\\d{2,})|(remove)))?$"_q,
 			ShowEditPersonalChannel,
 		},
 		{
@@ -2098,6 +2018,8 @@ void ResolveAndShowUniqueGift(
 		const auto &data = result.data();
 		session->data().processUsers(data.vusers());
 		if (const auto gift = Api::FromTL(session, data.vgift())) {
+			Core::App().hideMediaView();
+
 			using namespace ::Settings;
 			show->show(Box(
 				GlobalStarGiftBox,
@@ -2105,6 +2027,7 @@ void ResolveAndShowUniqueGift(
 				*gift,
 				StarGiftResaleInfo(),
 				st));
+			show->activate();
 		}
 	}).fail([=](const MTP::Error &error) {
 		clear();
