@@ -24,7 +24,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "lang/lang_keys.h"
 #include "main/main_session.h"
 #include "ui/chat/sponsored_message_bar.h"
-#include "ui/text/text_utilities.h" // Ui::Text::RichLangValue.
+#include "ui/text/text_utilities.h" // tr::rich.
 
 namespace Data {
 namespace {
@@ -285,7 +285,7 @@ void SponsoredMessages::request(not_null<History*> history, Fn<void()> done) {
 	request.requestId = _session->api().request(
 		MTPmessages_GetSponsoredMessages(
 			MTP_flags(0),
-			history->peer->input,
+			history->peer->input(),
 			MTPint()) // msg_id
 	).done([=](const MTPmessages_sponsoredMessages &result) {
 		parse(history, result);
@@ -346,7 +346,7 @@ void SponsoredMessages::requestForVideo(
 	request.requestId = _session->api().request(
 		MTPmessages_GetSponsoredMessages(
 			MTP_flags(Flag::f_msg_id),
-			peer->input,
+			peer->input(),
 			MTP_int(item->id.bare))
 	).done([=](const MTPmessages_sponsoredMessages &result) {
 		parseForVideo(peer, result);
@@ -544,7 +544,7 @@ void SponsoredMessages::append(
 		.mediaPhotoId = (mediaPhoto ? mediaPhoto->id : 0),
 		.mediaDocumentId = (mediaDocument ? mediaDocument->id : 0),
 		.backgroundEmojiId = BackgroundEmojiIdFromColor(data.vcolor()),
-		.colorIndex = ColorIndexFromColor(data.vcolor()),
+		.colorIndex = ColorIndexFromColor(data.vcolor()).value_or(0),
 		.isLinkInternal = !UrlRequiresConfirmation(qs(data.vurl())),
 		.isRecommended = data.is_recommended(),
 		.canReport = data.is_can_report(),
@@ -554,7 +554,7 @@ void SponsoredMessages::append(
 			tr::now,
 			lt_text,
 			{ .text = qs(*data.vsponsor_info()) },
-			Ui::Text::RichLangValue)
+			tr::rich)
 		: TextWithEntities();
 	auto additionalInfo = TextWithEntities::Simple(
 		data.vadditional_info() ? qs(*data.vadditional_info()) : QString());
