@@ -7,7 +7,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 */
 #pragma once
 
-#include "core/stars_amount.h"
+#include "core/credits_amount.h"
 #include "data/data_statistics_chart.h"
 
 #include <QtCore/QDateTime>
@@ -22,9 +22,9 @@ struct CreditsEarnStatistics final {
 			&& overallRevenue;
 	}
 	Data::StatisticalGraph revenueGraph;
-	StarsAmount currentBalance;
-	StarsAmount availableBalance;
-	StarsAmount overallRevenue;
+	CreditsAmount currentBalance;
+	CreditsAmount availableBalance;
+	CreditsAmount overallRevenue;
 	float64 usdRate = 0.;
 	bool isWithdrawalEnabled = false;
 	QDateTime nextWithdrawalAt;
