@@ -63,6 +63,8 @@ struct FileReferenceAccumulator {
 			push(data.vgift());
 		}, [&](const MTPDwebPageAttributeStarGiftCollection &data) {
 			push(data.vicons());
+		}, [&](const MTPDwebPageAttributeStarGiftAuction &data) {
+			push(data.vgift());
 		});
 	}
 	void push(const MTPStarGift &data) {
@@ -204,6 +206,12 @@ struct FileReferenceAccumulator {
 	void push(const MTPstories_Stories &data) {
 		push(data.data().vstories());
 	}
+	void push(const MTPusers_SavedMusic &data) {
+		data.match([&](const MTPDusers_savedMusic &data) {
+			push(data.vdocuments());
+		}, [](const MTPDusers_savedMusicNotModified &data) {
+		});
+	}
 
 	UpdatedFileReferences result;
 };
@@ -273,6 +281,10 @@ UpdatedFileReferences GetFileReferences(const MTPstories_Stories &data) {
 	return GetFileReferencesHelper(data);
 }
 
+UpdatedFileReferences GetFileReferences(const MTPusers_SavedMusic &data) {
+	return GetFileReferencesHelper(data);
+}
+
 UpdatedFileReferences GetFileReferences(const MTPMessageMedia &data) {
 	return GetFileReferencesHelper(data);
 }
