@@ -162,7 +162,7 @@ void Forum::requestTopics() {
 	const auto loadCount = firstLoad ? kTopicsFirstLoad : kTopicsPerPage;
 	_requestId = session().api().request(MTPmessages_GetForumTopics(
 		MTP_flags(0),
-		peer()->input,
+		peer()->input(),
 		MTPstring(), // q
 		MTP_int(_offset.date),
 		MTP_int(_offset.id),
@@ -366,10 +366,7 @@ void Forum::applyReceivedTopics(
 		const auto rootId = topic.match([&](const auto &data) {
 			return data.vid().v;
 		});
-		_staleRootIds.remove(rootId);
-		topic.match([&](const MTPDforumTopicDeleted &data) {
-			applyTopicDeleted(rootId);
-		}, [&](const MTPDforumTopic &data) {
+		const auto apply = [&](const MTPDforumTopic *fields = nullptr) {
 			_topicsDeleted.remove(rootId);
 			const auto i = _topics.find(rootId);
 			const auto creating = (i == end(_topics));
@@ -379,7 +376,9 @@ void Forum::applyReceivedTopics(
 					std::make_unique<ForumTopic>(this, rootId)
 				).first->second.get()
 				: i->second.get();
-			raw->applyTopic(data);
+			if (fields) {
+				raw->applyTopic(*fields);
+			}
 			if (creating) {
 				if (const auto last = _history->chatListMessage()
 					; last && last->topicRootId() == rootId) {
@@ -390,6 +389,19 @@ void Forum::applyReceivedTopics(
 			if (callback) {
 				callback(raw);
 			}
+		};
+
+		_staleRootIds.remove(rootId);
+		topic.match([&](const MTPDforumTopicDeleted &data) {
+			if (rootId != ForumTopic::kGeneralId) {
+				applyTopicDeleted(rootId);
+			} else {
+				// We shouldn't delete general topic in any case.
+				// Here this happens in bot forums, for example.
+				apply();
+			}
+		}, [&](const MTPDforumTopic &data) {
+			apply(&data);
 		});
 	}
 }
@@ -425,7 +437,7 @@ void Forum::requestSomeStale() {
 			Fn<void()> finish) {
 		return session().api().request(
 			MTPmessages_GetForumTopicsByID(
-				peer()->input,
+				peer()->input(),
 				MTP_vector<MTPint>(rootIds))
 		).done([=](const MTPmessages_ForumTopics &result) {
 			_staleRequestId = 0;
