@@ -584,8 +584,9 @@ public:
 
 	[[nodiscard]] int peerGiftsCount() const;
 
+	[[nodiscard]] MTPInputPeer input() const;
+
 	const PeerId id;
-	MTPinputPeer input = MTP_inputPeerEmpty();
 
 protected:
 	void updateNameDelayed(
@@ -674,6 +675,8 @@ void SetTopPinnedMessageId(
 	PeerData *migrated = nullptr);
 
 [[nodiscard]] uint64 BackgroundEmojiIdFromColor(const MTPPeerColor *color);
-[[nodiscard]] uint8 ColorIndexFromColor(const MTPPeerColor *color);
+[[nodiscard]] std::optional<uint8> ColorIndexFromColor(const MTPPeerColor *);
+
+[[nodiscard]] bool IsBotCanManageTopics(not_null<PeerData*>);
 
 } // namespace Data
