@@ -43,6 +43,8 @@ namespace Ui {
 class IconButton;
 class PopupMenu;
 class FlatLabel;
+class VerticalLayout;
+class RoundButton;
 struct ScrollToRequest;
 namespace Controls {
 enum class QuickDialogAction;
@@ -520,6 +522,8 @@ private:
 		uint8 more,
 		bool active);
 
+	void performDrag();
+
 	const not_null<Window::SessionController*> _controller;
 
 	not_null<IndexedList*> _shownList;
@@ -555,6 +559,8 @@ private:
 	bool _selectedRightButton = false;
 	bool _pressedRightButton = false;
 
+	Row *_qdragging = nullptr;
+
 	Row *_dragging = nullptr;
 	int _draggingIndex = -1;
 	int _aboveIndex = -1;
@@ -619,6 +625,8 @@ private:
 	object_ptr<SearchEmpty> _searchEmpty = { nullptr };
 	SearchState _searchEmptyState;
 	object_ptr<Ui::FlatLabel> _empty = { nullptr };
+	object_ptr<Ui::VerticalLayout> _emptyList = { nullptr };
+	object_ptr<Ui::RoundButton> _emptyButton = { nullptr };
 
 	Ui::DraggingScrollManager _draggingScroll;
 
