@@ -199,6 +199,38 @@ rpl::producer<not_null<QWheelEvent*>> List::verticalScrollEvents() const {
 	return _verticalScrollEvents.events();
 }
 
+bool List::toggledHidden() const {
+	return _hiddenInstant || _hiddenAnimated;
+}
+
+void List::setToggledHidden(bool hiddenInstant, bool hiddenAnimated) {
+	const auto hidden = (hiddenInstant || hiddenAnimated);
+	const auto hiddenChanged = (hidden != toggledHidden());
+	const auto hiddenInstantChanged = (_hiddenInstant != hiddenInstant);
+	const auto hiddenAnimatedChanged = (_hiddenAnimated != hiddenAnimated);
+	_hiddenInstant = hiddenInstant;
+	_hiddenAnimated = hiddenAnimated;
+	if (hiddenChanged) {
+		if (_hiddenInstant || !hiddenAnimatedChanged) {
+			_hiddenAnimation.stop();
+			setVisible(!toggledHidden());
+		} else {
+			const auto from = hidden ? 0. : 1.;
+			const auto till = hidden ? 1. : 0.;
+			_hiddenAnimation.start([=] {
+				if (!_hiddenAnimation.animating()) {
+					setVisible(!toggledHidden());
+				}
+				update();
+			}, from, till, st::fadeWrapDuration, anim::linear);
+			show();
+		}
+	} else if (hiddenInstantChanged && _hiddenInstant) {
+		_hiddenAnimation.stop();
+		setVisible(!toggledHidden());
+	}
+}
+
 void List::requestExpanded(bool expanded) {
 	if (_expanded != expanded) {
 		_expanded = expanded;
@@ -341,6 +373,10 @@ List::Layout List::computeLayout(float64 expanded) const {
 }
 
 void List::paintEvent(QPaintEvent *e) {
+	const auto hidden = _hiddenAnimation.value(toggledHidden() ? 1. : 0.);
+	if (hidden >= 1.) {
+		return;
+	}
 	const auto &st = _st.small;
 	const auto &full = _st.full;
 	const auto layout = computeLayout();
@@ -354,13 +390,18 @@ void List::paintEvent(QPaintEvent *e) {
 	};
 	const auto line = elerp(st.lineTwice, full.lineTwice) / 2.;
 	const auto photo = lerp(st.photo, full.photo);
-	const auto layered = layout.single < (photo + 4 * line);
+	const auto layered = (layout.single < (photo + 4 * line))
+		|| (hidden > 0.);
 	auto p = QPainter(this);
 	if (layered) {
 		ensureLayer();
 		auto q = QPainter(&_layer);
 		paint(q, layout, photo, line, true);
 		q.end();
+
+		if (hidden > 0.) {
+			p.setOpacity(1. - hidden);
+		}
 		p.drawImage(0, 0, _layer);
 	} else {
 		paint(p, layout, photo, line, false);
@@ -926,7 +967,7 @@ TextWithEntities List::computeTooltipText() const {
 			break;
 		}
 	}
-	auto sequence = Ui::Text::Bold(names.front());
+	auto sequence = tr::bold(names.front());
 	if (names.size() > 1) {
 		for (auto i = 1; i + 1 != names.size(); ++i) {
 			sequence = tr::lng_stories_click_to_view_and_one(
@@ -934,22 +975,22 @@ TextWithEntities List::computeTooltipText() const {
 				lt_accumulated,
 				sequence,
 				lt_user,
-				Ui::Text::Bold(names[i]),
-				Ui::Text::WithEntities);
+				tr::bold(names[i]),
+				tr::marked);
 		}
 		sequence = tr::lng_stories_click_to_view_and_last(
 			tr::now,
 			lt_accumulated,
 			sequence,
 			lt_user,
-			Ui::Text::Bold(names.back()),
-			Ui::Text::WithEntities);
+			tr::bold(names.back()),
+			tr::marked);
 	}
 	return tr::lng_stories_click_to_view(
 		tr::now,
 		lt_users,
 		sequence,
-		Ui::Text::WithEntities);
+		tr::marked);
 }
 
 void List::setShowTooltip(
