@@ -62,6 +62,7 @@ enum class SuggestionActions : uchar {
 	None,
 	Decline,
 	AcceptAndDecline,
+	GiftOfferActions,
 };
 
 struct HistoryMessageVia : RuntimeComponent<HistoryMessageVia, HistoryItem> {
@@ -164,6 +165,7 @@ struct HistoryMessageForwarded
 
 	PeerData *savedFromPeer = nullptr;
 	MsgId savedFromMsgId = 0;
+	TimeId savedFromDate = 0;
 
 	PeerData *savedFromSender = nullptr;
 	std::unique_ptr<HiddenSenderInfo> savedFromHiddenSenderInfo;
@@ -277,6 +279,7 @@ struct ReplyFields {
 	MsgId messageId = 0;
 	MsgId topMessageId = 0;
 	StoryId storyId = 0;
+	int todoItemId = 0;
 	uint32 quoteOffset : 30 = 0;
 	uint32 manualQuote : 1 = 0;
 	uint32 topicPost : 1 = 0;
@@ -454,9 +457,6 @@ public:
 		Style(const style::BotKeyboardButton &st) : _st(&st) {
 		}
 
-		virtual void startPaint(
-			QPainter &p,
-			const Ui::ChatStyle *st) const = 0;
 		virtual const style::TextStyle &textStyle() const = 0;
 
 		int buttonSkip() const;
@@ -475,8 +475,13 @@ public:
 			QPainter &p,
 			const Ui::ChatStyle *st,
 			const QRect &rect,
+			HistoryMessageMarkupButton::Color color,
 			Ui::BubbleRounding rounding,
 			float64 howMuchOver) const = 0;
+		virtual void paintButtonStart(
+			QPainter &p,
+			const Ui::ChatStyle *st,
+			HistoryMessageMarkupButton::Color color) const = 0;
 		virtual void paintButtonIcon(
 			QPainter &p,
 			const Ui::ChatStyle *st,
@@ -487,6 +492,7 @@ public:
 			QPainter &p,
 			const Ui::ChatStyle *st,
 			const QRect &rect,
+			HistoryMessageMarkupButton::Color color,
 			int outerWidth,
 			Ui::BubbleRounding rounding) const = 0;
 		virtual int minButtonWidth(
@@ -500,7 +506,8 @@ public:
 			const Ui::ChatStyle *st,
 			int outerWidth,
 			const ReplyKeyboard::Button &button,
-			Ui::BubbleRounding rounding) const;
+			Ui::BubbleRounding rounding,
+			bool paused) const;
 		friend class ReplyKeyboard;
 
 	};
@@ -524,7 +531,8 @@ public:
 		const Ui::ChatStyle *st,
 		Ui::BubbleRounding rounding,
 		int outerWidth,
-		const QRect &clip) const;
+		const QRect &clip,
+		bool paused) const;
 	ClickHandlerPtr getLink(QPoint point) const;
 	ClickHandlerPtr getLinkByIndex(int index) const;
 
@@ -551,12 +559,14 @@ private:
 		QRect rect;
 		int characters = 0;
 		float64 howMuchOver = 0.;
-		HistoryMessageMarkupButton::Type type;
+		HistoryMessageMarkupButton::Type type = {};
+		HistoryMessageMarkupButton::Color color = {};
 		std::shared_ptr<ReplyMarkupClickHandler> link;
 		mutable std::unique_ptr<Ui::RippleAnimation> ripple;
 	};
 	struct ButtonCoords {
-		int i, j;
+		int i = 0;
+		int j = 0;
 	};
 
 	void startAnimation(int i, int j, int direction);
@@ -621,8 +631,9 @@ struct HistoryMessageFactcheck
 	bool requested = false;
 };
 
-struct HistoryMessageSuggestedPost
-: RuntimeComponent<HistoryMessageSuggestedPost, HistoryItem> {
+struct HistoryMessageSuggestion
+: RuntimeComponent<HistoryMessageSuggestion, HistoryItem> {
+	std::shared_ptr<Data::UniqueGift> gift;
 	CreditsAmount price;
 	TimeId date = 0;
 	mtpRequestId requestId = 0;
@@ -712,12 +723,13 @@ enum class SuggestRefundType {
 	None,
 	User,
 	Admin,
+	Expired,
 };
 
 struct HistoryServiceSuggestFinish
 : RuntimeComponent<HistoryServiceSuggestFinish, HistoryItem>
 , HistoryServiceDependentData {
-	CreditsAmount successPrice;
+	CreditsAmount price;
 	SuggestRefundType refundType = SuggestRefundType::None;
 };
 
@@ -868,3 +880,8 @@ private:
 	mutable int _seekingCurrent = 0;
 
 };
+
+struct HistoryMessageSchedulePeriod
+: RuntimeComponent<HistoryMessageSchedulePeriod, HistoryItem> {
+	TimeId schedulePeriod = 0;
+};
