@@ -62,7 +62,8 @@ MediaGeneric::MediaGeneric(
 		Fn<void(std::unique_ptr<Part>)>)> generate,
 	MediaGenericDescriptor &&descriptor)
 : Media(parent)
-, _paintBg(std::move(descriptor.paintBg))
+, _paintBgFactory(std::move(descriptor.paintBgFactory))
+, _paintBg(_paintBgFactory ? _paintBgFactory() : nullptr)
 , _fullAreaLink(descriptor.fullAreaLink)
 , _maxWidthCap(descriptor.maxWidth)
 , _service(descriptor.service)
@@ -110,7 +111,11 @@ void MediaGeneric::draw(Painter &p, const PaintContext &context) const {
 	const auto outer = width();
 	if (outer < st::msgPadding.left() + st::msgPadding.right() + 1) {
 		return;
-	} else if (_paintBg) {
+	}
+	if (!_paintBg && _paintBgFactory) {
+		_paintBg = _paintBgFactory();
+	}
+	if (_paintBg) {
 		_paintBg(p, context, this);
 	} else if (_service) {
 		PainterHighQualityEnabler hq(p);
@@ -208,6 +213,7 @@ bool MediaGeneric::hasHeavyPart() const {
 }
 
 void MediaGeneric::unloadHeavyPart() {
+	_paintBg = nullptr;
 	for (const auto &entry : _entries) {
 		entry.object->unloadHeavyPart();
 	}
@@ -385,6 +391,35 @@ QSize TextDelimeterPart::countCurrentSize(int newWidth) {
 	return { newWidth, minHeight() };
 }
 
+LambdaGenericPart::LambdaGenericPart(
+	QSize size,
+	Fn<void(
+		Painter &p,
+		not_null<const MediaGeneric*> owner,
+		const PaintContext &context,
+		int outerWidth)> draw)
+: _size(size)
+, _draw(std::move(draw)) {
+}
+
+void LambdaGenericPart::draw(
+		Painter &p,
+		not_null<const MediaGeneric*> owner,
+		const PaintContext &context,
+		int outerWidth) const {
+	if (_draw) {
+		_draw(p, owner, context, outerWidth);
+	}
+}
+
+QSize LambdaGenericPart::countOptimalSize() {
+	return _size;
+}
+
+QSize LambdaGenericPart::countCurrentSize(int newWidth) {
+	return { newWidth, _size.height() };
+}
+
 StickerInBubblePart::StickerInBubblePart(
 	not_null<Element*> parent,
 	Element *replacing,
