@@ -26,7 +26,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "payments/payments_checkout_process.h" // Payments::CheckoutProcess
 #include "payments/payments_form.h" // Payments::InvoicePremiumGiftCode
 #include "settings/settings_common.h"
-#include "settings/settings_premium.h" // Settings::ShowPremium
+#include "settings/sections/settings_premium.h" // Settings::ShowPremium
 #include "ui/boxes/choose_date_time.h"
 #include "ui/boxes/confirm_box.h"
 #include "ui/effects/credits_graphics.h"
@@ -332,7 +332,7 @@ void CreateGiveawayBox(
 			(peer->isMegagroup()
 				? tr::lng_giveaway_new_about_group()
 				: tr::lng_giveaway_new_about())
-		) | rpl::map(Ui::Text::RichLangValue));
+		) | rpl::map(tr::rich));
 	{
 		const auto &padding = st::giveawayGiftCodeCoverDividerPadding;
 		Ui::AddSkip(box->verticalLayout(), padding.bottom());
@@ -1023,9 +1023,9 @@ void CreateGiveawayBox(
 				lt_link,
 				tr::lng_premium_gift_terms_link(
 				) | rpl::map([](const QString &t) {
-					return Ui::Text::Link(t, 1);
+					return tr::link(t, 1);
 				}),
-				Ui::Text::WithEntities),
+				tr::marked),
 			st::boxDividerLabel);
 		terms->setLink(1, std::make_shared<LambdaClickHandler>([=] {
 			box->closeBox();
@@ -1195,7 +1195,7 @@ void CreateGiveawayBox(
 					users,
 					lt_duration,
 					TextWithEntities{ duration },
-					Ui::Text::RichLangValue);
+					tr::rich);
 			}
 			return tr::lng_giveaway_prizes_additional(
 				tr::now,
@@ -1205,7 +1205,7 @@ void CreateGiveawayBox(
 				TextWithEntities{ prize },
 				lt_duration,
 				TextWithEntities{ duration },
-				Ui::Text::RichLangValue);
+				tr::rich);
 		});
 		auto creditsAdditionalAbout = rpl::combine(
 			state->additionalPrize.value(),
@@ -1218,7 +1218,7 @@ void CreateGiveawayBox(
 					tr::now,
 					lt_count,
 					credits,
-					Ui::Text::RichLangValue)
+					tr::rich)
 				: tr::lng_giveaway_prizes_additional_credits(
 					tr::now,
 					lt_count,
@@ -1230,8 +1230,8 @@ void CreateGiveawayBox(
 						tr::now,
 						lt_count,
 						credits,
-						Ui::Text::RichLangValue),
-					Ui::Text::RichLangValue);
+						tr::rich),
+					tr::rich);
 		});
 
 		auto creditsValueType = typeGroup->value(
@@ -1247,9 +1247,8 @@ void CreateGiveawayBox(
 					std::move(additionalAbout)),
 				rpl::conditional(
 					rpl::duplicate(creditsValueType),
-					tr::lng_giveaway_additional_credits_about(),
-					tr::lng_giveaway_additional_about()
-				) | Ui::Text::ToWithEntities()));
+					tr::lng_giveaway_additional_credits_about(tr::marked),
+					tr::lng_giveaway_additional_about(tr::marked))));
 		Ui::AddSkip(additionalWrap);
 	}
 
@@ -1487,15 +1486,15 @@ void CreateGiveawayBox(
 							? tr::lng_giveaway_created_body_group
 							: tr::lng_giveaway_created_body);
 					show->showToast({
-						.text = Ui::Text::Bold(
+						.text = tr::bold(
 							title(tr::now)).append('\n').append(
 								body(
 									tr::now,
 									lt_link,
-									Ui::Text::Link(
+									tr::link(
 										tr::lng_giveaway_created_link(
 											tr::now)),
-									Ui::Text::WithEntities)),
+									tr::marked)),
 						.filter = filter,
 						.adaptive = true,
 						.duration = kDoneTooltipDuration,
