@@ -8,8 +8,9 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "info/settings/info_settings_widget.h"
 
 #include "info/info_memento.h"
-#include "settings/settings_main.h"
-#include "settings/settings_information.h"
+#include "settings/sections/settings_main.h"
+#include "settings/sections/settings_information.h"
+#include "settings/settings_common_session.h"
 #include "ui/ui_utility.h"
 
 namespace Info {
@@ -202,8 +203,8 @@ const Ui::RoundRect *Widget::bottomSkipRounding() const {
 }
 
 rpl::producer<bool> Widget::desiredShadowVisibility() const {
-	return (_type == ::Settings::Main::Id()
-		|| _type == ::Settings::Information::Id())
+	return (_type == ::Settings::MainId()
+		|| _type == ::Settings::InformationId())
 		? ContentWidget::desiredShadowVisibility()
 		: rpl::single(true);
 }
@@ -256,9 +257,13 @@ void Widget::fillTopBarMenu(const Ui::Menu::MenuCallback &addAction) {
 
 void Widget::saveState(not_null<Memento*> memento) {
 	memento->setScrollTop(scrollTopSave());
+	auto sectionState = std::any();
+	_inner->sectionSaveState(sectionState);
+	memento->setSectionState(std::move(sectionState));
 }
 
 void Widget::restoreState(not_null<Memento*> memento) {
+	_inner->sectionRestoreState(memento->sectionState());
 	scrollTopRestore(memento->scrollTop());
 }
 
