@@ -23,7 +23,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "ui/widgets/tooltip.h"
 #include "ui/ui_utility.h"
 #include "lang/lang_keys.h"
-#include "settings/settings_premium.h"
+#include "settings/sections/settings_premium.h"
 #include "window/window_session_controller.h"
 #include "styles/style_info.h"
 #include "styles/style_widgets.h"
@@ -173,8 +173,9 @@ void ListController::setupUnlock() {
 				rpl::single(upto * 1.),
 				lt_link,
 				tr::lng_similar_channels_premium_all_link(
-				) | Ui::Text::ToBold() | Ui::Text::ToLink(),
-				Ui::Text::RichLangValue),
+					tr::bold
+				) | rpl::map(tr::link),
+				tr::rich),
 		st::similarChannelsLockAbout);
 	about->setClickHandlerFilter([=](const auto &...) {
 		const auto window = _controller->parentController();
