@@ -65,11 +65,11 @@ class ItemZoom final
 	, public Ui::AbstractTooltipShower {
 public:
 	ItemZoom(
-		not_null<RpWidget*> parent,
+		not_null<Ui::PopupMenu*> parent,
 		const not_null<Delegate*> delegate,
 		const style::Menu &st)
 	: Ui::Menu::Action(
-		parent,
+		parent->menu(),
 		st,
 		Ui::CreateChild<QAction>(parent),
 		nullptr,
@@ -85,7 +85,7 @@ public:
 		AbstractButton::setDisabled(true);
 
 		const auto processTooltip = [=](not_null<Ui::RpWidget*> w) {
-			w->events() | rpl::start_with_next([=](not_null<QEvent*> e) {
+			w->events() | rpl::on_next([=](not_null<QEvent*> e) {
 				if (e->type() == QEvent::Enter) {
 					Ui::Tooltip::Show(1000, this);
 				} else if (e->type() == QEvent::Leave) {
@@ -113,7 +113,7 @@ public:
 			this,
 			st::defaultRippleAnimationBgOver);
 		plus->resize(Size(st::ivZoomButtonsSize));
-		plus->paintRequest() | rpl::start_with_next([=, fg = _st.itemFg] {
+		plus->paintRequest() | rpl::on_next([=, fg = _st.itemFg] {
 			auto p = QPainter(plus);
 			p.setPen(fg);
 			p.setFont(st::normalFont);
@@ -135,7 +135,7 @@ public:
 			this,
 			st::defaultRippleAnimationBgOver);
 		minus->resize(Size(st::ivZoomButtonsSize));
-		minus->paintRequest() | rpl::start_with_next([=, fg = _st.itemFg] {
+		minus->paintRequest() | rpl::on_next([=, fg = _st.itemFg] {
 			auto p = QPainter(minus);
 			const auto r = minus->rect();
 			p.setPen(fg);
@@ -164,7 +164,7 @@ public:
 		}
 
 		_delegate->ivZoomValue(
-		) | rpl::start_with_next([this](int value) {
+		) | rpl::on_next([this](int value) {
 			_text.setText(_st.itemStyle, QString::number(value) + '%');
 			update();
 		}, lifetime());
@@ -172,7 +172,7 @@ public:
 		rpl::combine(
 			sizeValue(),
 			reset->sizeValue()
-		) | rpl::start_with_next([=](const QSize &size, const QSize &) {
+		) | rpl::on_next([=](const QSize &size, const QSize &) {
 			reset->setFullWidth(0
 				+ resetLabel->width()
 				+ st::ivResetZoomInnerPadding);
@@ -420,7 +420,7 @@ void Controller::updateTitleGeometry(int newWidth) const {
 		0,
 		newWidth,
 		st::ivSubtitleHeight);
-	_subtitleWrap->paintRequest() | rpl::start_with_next([=](QRect clip) {
+	_subtitleWrap->paintRequest() | rpl::on_next([=](QRect clip) {
 		QPainter(_subtitleWrap.get()).fillRect(clip, st::windowBg);
 	}, _subtitleWrap->lifetime());
 
@@ -462,7 +462,7 @@ void Controller::initControls() {
 		return prefix + ' ' + QChar(0x2014) + ' ' + subtitle;
 	});
 	_windowTitleText.value(
-	) | rpl::start_with_next([=](const QString &title) {
+	) | rpl::on_next([=](const QString &title) {
 		_window->setWindowTitle(title);
 	}, _subtitle->lifetime());
 
@@ -491,7 +491,7 @@ void Controller::initControls() {
 	});
 
 	_back->toggledValue(
-	) | rpl::start_with_next([=](bool toggled) {
+	) | rpl::on_next([=](bool toggled) {
 		_subtitleBackShift.start(
 			[=] { updateTitleGeometry(_window->body()->width()); },
 			toggled ? 0. : 1.,
@@ -501,7 +501,7 @@ void Controller::initControls() {
 	_back->hide(anim::type::instant);
 
 	_forward->toggledValue(
-	) | rpl::start_with_next([=](bool toggled) {
+	) | rpl::on_next([=](bool toggled) {
 		_subtitleForwardShift.start(
 			[=] { updateTitleGeometry(_window->body()->width()); },
 			toggled ? 0. : 1.,
@@ -573,7 +573,7 @@ QByteArray Controller::fillInChannelValuesScript(
 	auto result = QByteArray();
 	for (auto &[id, in] : inChannelValues) {
 		if (_inChannelSubscribed.emplace(id).second) {
-			std::move(in) | rpl::start_with_next([=](bool in) {
+			std::move(in) | rpl::on_next([=](bool in) {
 				if (_ready) {
 					_webview->eval(toggleInChannelScript(id, in));
 				} else {
@@ -605,22 +605,22 @@ void Controller::createWindow() {
 	) | rpl::filter([=](QWindow *focused) {
 		const auto handle = window->window()->windowHandle();
 		return _webview && handle && (focused == handle);
-	}) | rpl::start_with_next([=] {
+	}) | rpl::on_next([=] {
 		setInnerFocus();
 	}, window->lifetime());
 
 	initControls();
 
-	window->body()->widthValue() | rpl::start_with_next([=](int width) {
+	window->body()->widthValue() | rpl::on_next([=](int width) {
 		updateTitleGeometry(width);
 	}, _subtitle->lifetime());
 
-	window->setGeometry(_delegate->ivGeometry());
+	window->setGeometry(_delegate->ivGeometry(window));
 	window->setMinimumSize({ st::windowMinWidth, st::windowMinHeight });
 
 	window->geometryValue(
 	) | rpl::distinct_until_changed(
-	) | rpl::skip(1) | rpl::start_with_next([=] {
+	) | rpl::skip(1) | rpl::on_next([=] {
 		_delegate->ivSaveGeometry(window);
 	}, window->lifetime());
 
@@ -628,12 +628,12 @@ void Controller::createWindow() {
 	rpl::combine(
 		window->body()->sizeValue(),
 		_subtitleWrap->heightValue()
-	) | rpl::start_with_next([=](QSize size, int title) {
+	) | rpl::on_next([=](QSize size, int title) {
 		_container->setGeometry(QRect(QPoint(), size).marginsRemoved(
 			{ 0, title, 0, 0 }));
 	}, _container->lifetime());
 
-	_container->paintRequest() | rpl::start_with_next([=](QRect clip) {
+	_container->paintRequest() | rpl::on_next([=](QRect clip) {
 		QPainter(_container).fillRect(clip, st::windowBg);
 	}, _container->lifetime());
 
@@ -656,13 +656,13 @@ void Controller::createWebview(const Webview::StorageId &storageId) {
 
 	if (const auto webviewZoomController = raw->zoomController()) {
 		webviewZoomController->zoomValue(
-		) | rpl::start_with_next([this](int value) {
+		) | rpl::on_next([this](int value) {
 			if (value > 0) {
 				_delegate->ivSetZoom(value);
 			}
 		}, lifetime());
 		_delegate->ivZoomValue(
-		) | rpl::start_with_next([=](int value) {
+		) | rpl::on_next([=](int value) {
 			webviewZoomController->setZoom(value);
 		}, lifetime());
 	}
@@ -673,7 +673,7 @@ void Controller::createWebview(const Webview::StorageId &storageId) {
 	});
 
 	window->events(
-	) | rpl::start_with_next([=](not_null<QEvent*> e) {
+	) | rpl::on_next([=](not_null<QEvent*> e) {
 		if (e->type() == QEvent::Close) {
 			close();
 		} else if (e->type() == QEvent::KeyPress) {
@@ -728,7 +728,7 @@ void Controller::createWebview(const Webview::StorageId &storageId) {
 	});
 
 	_container->sizeValue(
-	) | rpl::start_with_next([=](QSize size) {
+	) | rpl::on_next([=](QSize size) {
 		if (const auto widget = raw->widget()) {
 			widget->setGeometry(QRect(QPoint(), size));
 		}
@@ -817,7 +817,7 @@ void Controller::createWebview(const Webview::StorageId &storageId) {
 					Lang::Updated(),
 					style::PaletteChanged(),
 					_delegate->ivZoomValue() | rpl::to_empty
-				) | rpl::start_with_next([=] {
+				) | rpl::on_next([=] {
 					_updateStyles.call();
 				}, _webview->lifetime());
 			}
@@ -876,7 +876,7 @@ void Controller::createWebview(const Webview::StorageId &storageId) {
 	});
 
 	raw->navigationHistoryState(
-	) | rpl::start_with_next([=](Webview::NavigationHistoryState state) {
+	) | rpl::on_next([=](Webview::NavigationHistoryState state) {
 		_back->toggle(
 			state.canGoBack || state.canGoForward,
 			anim::type::normal);
@@ -925,12 +925,12 @@ void Controller::showWebviewError(TextWithEntities text) {
 	});
 	wrap->show();
 
-	wrap->widthValue() | rpl::start_with_next([=](int width) {
+	wrap->widthValue() | rpl::on_next([=](int width) {
 		error->resizeToWidth(width);
 		wrap->resize(width, error->height());
 	}, wrap->lifetime());
 
-	_container->sizeValue() | rpl::start_with_next([=](QSize size) {
+	_container->sizeValue() | rpl::on_next([=](QSize size) {
 		wrap->setGeometry(0, 0, size.width(), size.height() * 2 / 3);
 	}, wrap->lifetime());
 }
@@ -1210,7 +1210,7 @@ void Controller::showShareMenu() {
 			_window->body().get(),
 			Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint));
 	}
-	_window->body()->sizeValue() | rpl::start_with_next([=](QSize size) {
+	_window->body()->sizeValue() | rpl::on_next([=](QSize size) {
 		const auto widget = _shareHidesContent
 			? _shareWrap.get()
 			: _shareContainer.get();
@@ -1224,7 +1224,7 @@ void Controller::showShareMenu() {
 	_shareFocus = result.focus;
 	_shareHide = result.hide;
 
-	std::move(result.destroyRequests) | rpl::start_with_next([=] {
+	std::move(result.destroyRequests) | rpl::on_next([=] {
 		destroyShareMenu();
 	}, _shareWrap->lifetime());
 
