@@ -45,6 +45,10 @@ class PromoSuggestions;
 class Passkeys;
 } // namespace Data
 
+namespace Settings {
+class FaqSuggestions;
+} // namespace Settings
+
 namespace HistoryView::Reactions {
 class CachedIconFactory;
 } // namespace HistoryView::Reactions
@@ -205,6 +209,9 @@ public:
 	[[nodiscard]] Data::Passkeys &passkeys() const {
 		return *_passkeys;
 	}
+	[[nodiscard]] Settings::FaqSuggestions &faqSuggestions() const {
+		return *_faqSuggestions;
+	}
 	[[nodiscard]] auto cachedReactionIconFactory() const
 	-> HistoryView::Reactions::CachedIconFactory & {
 		return *_cachedReactionIconFactory;
@@ -310,6 +317,7 @@ private:
 	const std::unique_ptr<Data::Credits> _credits;
 	const std::unique_ptr<Data::PromoSuggestions> _promoSuggestions;
 	const std::unique_ptr<Data::Passkeys> _passkeys;
+	const std::unique_ptr<Settings::FaqSuggestions> _faqSuggestions;
 
 	using ReactionIconFactory = HistoryView::Reactions::CachedIconFactory;
 	const std::unique_ptr<ReactionIconFactory> _cachedReactionIconFactory;
