@@ -19,7 +19,12 @@ struct SendAction;
 struct SendOptions;
 } // namespace Api
 
+namespace Calls {
+class GroupCall;
+} // namespace Calls
+
 namespace Data {
+class GroupCall;
 struct ReactionId;
 } // namespace Data
 
@@ -57,11 +62,18 @@ class Controller;
 struct ReplyAreaData {
 	PeerData *peer = nullptr;
 	StoryId id = 0;
+	std::shared_ptr<Data::GroupCall> videoStream;
 
 	friend inline auto operator<=>(ReplyAreaData, ReplyAreaData) = default;
 	friend inline bool operator==(ReplyAreaData, ReplyAreaData) = default;
 };
 
+enum class ReplyAreaType {
+	Reply,
+	Comment,
+	VideoStreamComment,
+};
+
 class ReplyArea final : public base::has_weak_ptr {
 public:
 	explicit ReplyArea(not_null<Controller*> controller);
@@ -80,7 +92,9 @@ public:
 	[[nodiscard]] bool ignoreWindowMove(QPoint position) const;
 	void tryProcessKeyInput(not_null<QKeyEvent*> e);
 
-	[[nodiscard]] not_null<Ui::RpWidget*> likeAnimationTarget() const;
+	[[nodiscard]] Ui::RpWidget *likeAnimationTarget() const;
+
+	void updateVideoStream(not_null<Calls::GroupCall*> videoStream);
 
 private:
 	class Cant;
@@ -154,13 +168,15 @@ private:
 	void chooseAttach(std::optional<bool> overrideSendImagesAsPhotos);
 
 	[[nodiscard]] Fn<SendMenu::Details()> sendMenuDetails() const;
+	[[nodiscard]] rpl::producer<int> starsPerMessageValue() const;
 
 	void showPremiumToast(not_null<DocumentData*> emoji);
 	[[nodiscard]] bool showSlowmodeError();
 
 	const not_null<Controller*> _controller;
-	rpl::variable<bool> _isComment;
+	rpl::variable<ReplyAreaType> _type;
 	rpl::variable<int> _starsForMessage;
+	base::weak_ptr<Calls::GroupCall> _videoStream;
 
 	const std::unique_ptr<HistoryView::ComposeControls> _controls;
 	std::unique_ptr<Cant> _cant;
