@@ -39,6 +39,7 @@ private:
 	bool handleHideWorkaround(QOpenGLFunctions &f);
 
 	void paintBackground() override;
+	void paintVideoStream() override;
 	void paintTransformedVideoFrame(ContentGeometry geometry) override;
 	void paintTransformedStaticContent(
 		const QImage &image,
@@ -49,7 +50,8 @@ private:
 	void paintTransformedContent(
 		not_null<QOpenGLShaderProgram*> program,
 		ContentGeometry geometry,
-		bool fillTransparentBackground);
+		bool fillTransparentBackground,
+		QRectF textureRect = QRectF(0., 0., 1., 1.));
 	void paintRadialLoading(
 		QRect inner,
 		bool radial,
@@ -75,6 +77,11 @@ private:
 		QRect rect,
 		float64 opacity = 1.) override;
 
+	void paintRecognitionOverlay(
+		const QImage &image,
+		ContentGeometry geometry,
+		float64 opacity);
+
 	//void invalidate();
 
 	void paintUsingRaster(
@@ -145,7 +152,7 @@ private:
 	static constexpr auto kStoriesSiblingPartsCount = 4;
 	Ui::GL::Image _storiesSiblingParts[kStoriesSiblingPartsCount];
 
-	static constexpr auto kControlsCount = 6;
+	static constexpr auto kControlsCount = 7;
 	[[nodiscard]] Control controlMeta(Over control) const;
 
 	// Last one is for the over circle image.
