@@ -11,6 +11,10 @@ namespace Core {
 enum class QuitReason;
 } // namespace Core
 
+namespace Data {
+class LocationPoint;
+} // namespace Data
+
 namespace Platform {
 
 void start();
@@ -50,6 +54,7 @@ void NewVersionLaunched(int oldVersion);
 [[nodiscard]] QString ApplicationIconName();
 [[nodiscard]] bool PreventsQuit(Core::QuitReason reason);
 [[nodiscard]] QString ExecutablePathForShortcuts();
+void LaunchMaps(const Data::LocationPoint &point, Fn<void()> fail);
 
 #if QT_VERSION < QT_VERSION_CHECK(6, 5, 0)
 [[nodiscard]] std::optional<bool> IsDarkMode();
