@@ -12,6 +12,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "core/core_cloud_password.h"
 #include "lang/lang_keys.h"
 #include "settings/cloud_password/settings_cloud_password_common.h"
+#include "settings/settings_common.h"
 #include "settings/cloud_password/settings_cloud_password_email_confirm.h"
 #include "settings/cloud_password/settings_cloud_password_email.h"
 #include "settings/cloud_password/settings_cloud_password_hint.h"
@@ -66,6 +67,10 @@ private:
 
 	rpl::lifetime _requestLifetime;
 
+	QPointer<Ui::RpWidget> _changePasswordButton;
+	QPointer<Ui::RpWidget> _changeEmailButton;
+	QPointer<Ui::RpWidget> _disableButton;
+
 };
 
 rpl::producer<QString> Manage::title() {
@@ -110,7 +115,7 @@ void Manage::setupContent() {
 		return;
 	}
 	cloudPassword().state(
-	) | rpl::start_with_next([=](const Core::CloudPasswordState &state) {
+	) | rpl::on_next([=](const Core::CloudPasswordState &state) {
 		if (!_requestLifetime && !state.hasPassword) {
 			quit();
 		}
@@ -134,22 +139,24 @@ void Manage::setupContent() {
 	});
 
 	Ui::AddSkip(content);
-	AddButtonWithIcon(
+	const auto changePasswordButton = AddButtonWithIcon(
 		content,
 		tr::lng_settings_cloud_password_manage_password_change(),
 		st::settingsButton,
-		{ &st::menuIconPermissions }
-	)->setClickedCallback([=] {
+		{ &st::menuIconPermissions });
+	_changePasswordButton = changePasswordButton;
+	changePasswordButton->setClickedCallback([=] {
 		showOtherAndRememberPassword(CloudPasswordInputId());
 	});
-	AddButtonWithIcon(
+	const auto changeEmailButton = AddButtonWithIcon(
 		content,
 		state->hasRecovery
 			? tr::lng_settings_cloud_password_manage_email_change()
 			: tr::lng_settings_cloud_password_manage_email_new(),
 		st::settingsButton,
-		{ &st::menuIconRecoveryEmail }
-	)->setClickedCallback([=] {
+		{ &st::menuIconRecoveryEmail });
+	_changeEmailButton = changeEmailButton;
+	changeEmailButton->setClickedCallback([=] {
 		auto data = stepData();
 		data.setOnlyRecoveryEmail = true;
 		setStepData(std::move(data));
@@ -158,6 +165,16 @@ void Manage::setupContent() {
 	});
 	Ui::AddSkip(content);
 
+	showFinishes() | rpl::take(1) | rpl::on_next([=] {
+		controller()->checkHighlightControl(
+			u"2sv/change"_q,
+			_changePasswordButton);
+		controller()->checkHighlightControl(
+			u"2sv/change-email"_q,
+			_changeEmailButton);
+		controller()->checkHighlightControl("2sv/disable"_q, _disableButton);
+	}, lifetime());
+
 	using Divider = CloudPassword::OneEdgeBoxContentDivider;
 	const auto divider = Ui::CreateChild<Divider>(this);
 	divider->lower();
@@ -172,12 +189,12 @@ void Manage::setupContent() {
 	rpl::combine(
 		about->geometryValue(),
 		content->widthValue()
-	) | rpl::start_with_next([=](QRect r, int w) {
+	) | rpl::on_next([=](QRect r, int w) {
 		r.setWidth(w);
 		divider->setGeometry(r);
 	}, divider->lifetime());
 	_isBottomFillerShown.value(
-	) | rpl::start_with_next([=](bool shown) {
+	) | rpl::on_next([=](bool shown) {
 		divider->skipEdge(Qt::BottomEdge, shown);
 	}, divider->lifetime());
 
@@ -197,7 +214,7 @@ base::weak_qptr<Ui::RpWidget> Manage::createPinnedToBottom(
 			QString(),
 			false,
 			QString()
-		) | rpl::start_with_error_done([=](const QString &type) {
+		) | rpl::on_error_done([=](const QString &type) {
 			AbstractStep::isPasswordInvalidError(type);
 		}, [=] {
 			setStepData(StepData());
@@ -222,6 +239,7 @@ base::weak_qptr<Ui::RpWidget> Manage::createPinnedToBottom(
 		std::move(callback));
 
 	_isBottomFillerShown = base::take(bottomButton.isBottomFillerShown);
+	_disableButton = bottomButton.button.get();
 
 	return bottomButton.content;
 }
