@@ -52,14 +52,14 @@ public:
 		ColorFactory cache)
 	: Ui::RippleButton(parent, st::defaultRippleAnimation) {
 		text(
-		) | rpl::start_with_next([this](const QString &t) {
+		) | rpl::on_next([this](const QString &t) {
 			const auto height = st::stickersHeaderBadgeFont->height;
 			resize(
 				st::stickersHeaderBadgeFont->width(t) + height,
 				height);
 			update();
 		}, lifetime());
-		paintRequest() | rpl::start_with_next([this, cache, text] {
+		paintRequest() | rpl::on_next([this, cache, text] {
 			auto p = QPainter(this);
 			const auto colors = cache();
 			const auto r = rect();
@@ -102,7 +102,7 @@ public:
 	Window::ChatThemeValueFromPeer(
 		controller,
 		peer
-	) | rpl::start_with_next([=](std::shared_ptr<Ui::ChatTheme> &&theme) {
+	) | rpl::on_next([=](std::shared_ptr<Ui::ChatTheme> &&theme) {
 		state->theme = std::move(theme);
 	}, widget->lifetime());
 
@@ -163,7 +163,7 @@ void FillSponsoredMessageBar(
 		container,
 		st::defaultRippleAnimationBgOver);
 	widget->show();
-	container->sizeValue() | rpl::start_with_next([=](const QSize &s) {
+	container->sizeValue() | rpl::on_next([=](const QSize &s) {
 		widget->resize(s);
 	}, widget->lifetime());
 	widget->setAcceptBoth();
@@ -251,7 +251,7 @@ void FillSponsoredMessageBar(
 			st::dialogsCancelSearchInPeer);
 	if (rightHide) {
 		container->sizeValue(
-		) | rpl::start_with_next([=](const QSize &s) {
+		) | rpl::on_next([=](const QSize &s) {
 			rightHide->moveToRight(st::buttonRadius, st::lineWidth);
 		}, rightHide->lifetime());
 		rightHide->setClickedCallback(
@@ -378,14 +378,14 @@ void FillSponsoredMessageBar(
 				state->rightPhotoImage);
 		}
 	};
-	widget->paintRequest() | rpl::start_with_next([=] {
+	widget->paintRequest() | rpl::on_next([=] {
 		auto p = QPainter(widget);
 		draw(p);
 	}, widget->lifetime());
 	rpl::combine(
 		state->lastPaintedContentTop.value(),
 		state->lastPaintedContentLineAmount.value()
-	) | rpl::distinct_until_changed() | rpl::start_with_next([=](
+	) | rpl::distinct_until_changed() | rpl::on_next([=](
 			int lastTop,
 			int lastLines) {
 		const auto bottomPadding = st::msgReplyPadding.top();
@@ -411,7 +411,7 @@ void FillSponsoredMessageBar(
 	{
 		const auto top = Ui::CreateChild<PlainShadow>(widget);
 		const auto bottom = Ui::CreateChild<PlainShadow>(widget);
-		widget->sizeValue() | rpl::start_with_next([=] (const QSize &s) {
+		widget->sizeValue() | rpl::on_next([=] (const QSize &s) {
 			top->show();
 			top->raise();
 			top->resizeToWidth(s.width());
