@@ -14,6 +14,7 @@ struct FlatLabel;
 namespace Ui {
 
 class RoundButton;
+class RpWidget;
 
 void SetButtonTwoLabels(
     not_null<Ui::RoundButton*> button,
@@ -23,4 +24,13 @@ void SetButtonTwoLabels(
     const style::FlatLabel &subst,
     const style::color *textFg = nullptr);
 
+void SetButtonTwoLabels(
+    not_null<Ui::RpWidget*> button,
+    int singleLineTextTop,
+    rpl::producer<TextWithEntities> title,
+    rpl::producer<TextWithEntities> subtitle,
+    const style::FlatLabel &st,
+    const style::FlatLabel &subst,
+    const style::color *textFg = nullptr);
+
 } // namespace Ui
\ No newline at end of file
