@@ -513,33 +513,33 @@ object_ptr<RoundButton> FilterLinkProcessButton(
 		case FilterLinkHeaderType::AddingFilter:
 			return badge.isEmpty()
 				? tr::lng_filters_by_link_add_no(
-					Ui::Text::WithEntities
+					tr::marked
 				) | with(QString())
 				: tr::lng_filters_by_link_add_button(
 					lt_folder,
 					rpl::single(title),
-					Ui::Text::WithEntities
+					tr::marked
 				) | with(badge);
 		case FilterLinkHeaderType::AddingChats:
 			return badge.isEmpty()
 				? tr::lng_filters_by_link_join_no(
-					Ui::Text::WithEntities
+					tr::marked
 				) | with(QString())
 				: tr::lng_filters_by_link_and_join_button(
 					lt_count,
 					rpl::single(float64(count)),
-					Ui::Text::WithEntities) | with(badge);
+					tr::marked) | with(badge);
 		case FilterLinkHeaderType::AllAdded:
-			return tr::lng_box_ok(Ui::Text::WithEntities) | with(QString());
+			return tr::lng_box_ok(tr::marked) | with(QString());
 		case FilterLinkHeaderType::Removing:
 			return badge.isEmpty()
 				? tr::lng_filters_by_link_remove_button(
-					Ui::Text::WithEntities
+					tr::marked
 				) | with(QString())
 				: tr::lng_filters_by_link_and_quit_button(
 					lt_count,
 					rpl::single(float64(count)),
-					Ui::Text::WithEntities) | with(badge);
+					tr::marked) | with(badge);
 		}
 		Unexpected("Type in FilterLinkProcessButton.");
 	}) | rpl::flatten_latest();
