@@ -90,6 +90,10 @@ namespace HistoryView::Reactions {
 class CachedIconFactory;
 } // namespace HistoryView::Reactions
 
+namespace Settings {
+struct HighlightArgs;
+} // namespace Settings
+
 namespace Window {
 
 using GifPauseReason = ChatHelpers::PauseReason;
@@ -700,6 +704,17 @@ public:
 	void showStarGiftAuction(const QString &slug);
 	void showStarGiftAuction(uint64 giftId);
 
+	void showCloudPassword(const QString &highlightId = QString());
+
+	void setHighlightControlId(const QString &id);
+	[[nodiscard]] QString highlightControlId() const;
+	[[nodiscard]] bool takeHighlightControlId(const QString &id);
+	void checkHighlightControl(
+		const QString &id,
+		QWidget *widget,
+		Settings::HighlightArgs &&args);
+	void checkHighlightControl(const QString &id, QWidget *widget);
+
 	[[nodiscard]] rpl::lifetime &lifetime() {
 		return _lifetime;
 	}
@@ -820,6 +835,7 @@ private:
 	rpl::lifetime _savedSubsectionTabsLifetime;
 
 	rpl::lifetime _starGiftAuctionLifetime;
+	rpl::lifetime _showCloudPasswordLifetime;
 
 	rpl::lifetime _lifetime;
 
