@@ -178,6 +178,13 @@ public:
 		rpl::producer<QString> placeholder = nullptr,
 		const TextWithTags &value = TextWithTags());
 
+	QAccessible::Role accessibilityRole() override {
+		return QAccessible::Role::EditableText;
+	}
+	QString accessibilityName() override {
+		return _placeholderFull.current();
+	}
+
 	[[nodiscard]] const style::InputField &st() const {
 		return _st;
 	}
@@ -189,6 +196,7 @@ public:
 	void setMaxLength(int maxLength);
 	void setMinHeight(int minHeight);
 	void setMaxHeight(int maxHeight);
+	void setMode(Mode mode);
 
 	[[nodiscard]] const TextWithTags &getTextWithTags() const {
 		return _lastTextWithTags;
@@ -301,7 +309,6 @@ public:
 		SubmitSettings settings,
 		Qt::KeyboardModifiers modifiers);
 	void customUpDown(bool isCustom);
-	void customTab(bool isCustom);
 	int borderAnimationStart() const;
 
 	not_null<QTextDocument*> document();
@@ -353,7 +360,7 @@ public:
 
 	[[nodiscard]] rpl::producer<> heightChanges() const;
 	[[nodiscard]] rpl::producer<bool> focusedChanges() const;
-	[[nodiscard]] rpl::producer<> tabbed() const;
+	[[nodiscard]] rpl::producer<not_null<bool*>> tabbed() const;
 	[[nodiscard]] rpl::producer<> cancelled() const;
 	[[nodiscard]] rpl::producer<> changes() const;
 	[[nodiscard]] rpl::producer<Qt::KeyboardModifiers> submits() const;
@@ -598,7 +605,6 @@ private:
 	bool _inHeightCheck = false;
 
 	bool _customUpDown = false;
-	bool _customTab = false;
 
 	rpl::variable<QString> _placeholderFull;
 	QString _placeholder;
@@ -646,7 +652,7 @@ private:
 
 	rpl::event_stream<bool> _focusedChanges;
 	rpl::event_stream<> _heightChanges;
-	rpl::event_stream<> _tabbed;
+	rpl::event_stream<not_null<bool*>> _tabbed;
 	rpl::event_stream<> _cancelled;
 	rpl::event_stream<> _changes;
 	rpl::event_stream<Qt::KeyboardModifiers> _submits;
@@ -665,6 +671,7 @@ struct LengthLimitLabelOptions {
 	RpWidget *customParent = nullptr;
 	std::optional<int> customThreshold = std::nullopt;
 	Fn<QPoint(QSize parent, QSize label)> customUpdatePosition;
+	Fn<int()> customCharactersCount;
 	int limitLabelTop = 0;
 };
 void AddLengthLimitLabel(
