@@ -233,7 +233,7 @@ FlatLabel::FlatLabel(
 	textUpdated();
 	std::move(
 		text
-	) | rpl::start_with_next([this](const QString &value) {
+	) | rpl::on_next([this](const QString &value) {
 		setText(value);
 	}, lifetime());
 	init();
@@ -253,7 +253,7 @@ FlatLabel::FlatLabel(
 	textUpdated();
 	std::move(
 		text
-	) | rpl::start_with_next([=](const TextWithEntities &value) {
+	) | rpl::on_next([=](const TextWithEntities &value) {
 		setMarkedText(value, context);
 	}, lifetime());
 	init();
@@ -944,6 +944,10 @@ void FlatLabel::setTextColorOverride(std::optional<QColor> color) {
 }
 
 void FlatLabel::paintEvent(QPaintEvent *e) {
+	if (_opacity == 0.) {
+		return;
+	}
+
 	Painter p(this);
 	p.setOpacity(_opacity);
 	if (_textColorOverride) {
