@@ -76,6 +76,13 @@ public:
 		const style::LabelSimple &st = st::defaultLabelSimple,
 		const QString &value = QString());
 
+	QAccessible::Role accessibilityRole() override {
+		return QAccessible::Role::StaticText;
+	}
+	QString accessibilityName() override {
+		return _fullText;
+	}
+
 	// This method also resizes the label.
 	void setText(const QString &newText, bool *outTextChanged = nullptr);
 
@@ -118,6 +125,13 @@ public:
 		const style::PopupMenu &stMenu = st::defaultPopupMenu,
 		const Text::MarkedContext &context = {});
 
+	QAccessible::Role accessibilityRole() override {
+		return QAccessible::Role::StaticText;
+	}
+	QString accessibilityName() override {
+		return _text.toString();
+	}
+
 	[[nodiscard]] const style::FlatLabel &st() const {
 		return _st;
 	}
@@ -279,6 +293,7 @@ public:
 		QWidget *parent,
 		object_ptr<RpWidget> &&child,
 		const style::margins &padding,
+		const style::DividerBar &st = st::defaultDividerBar,
 		RectParts parts = RectPart::Top | RectPart::Bottom);
 
 protected:
