@@ -107,6 +107,9 @@ public:
 
 	void setSelected(int selected, bool isMouseSelection);
 
+	[[nodiscard]] bool hasMouseMoved(const QPoint &globalPosition) const;
+	void mouseMoved();
+
 	[[nodiscard]] rpl::producer<> resizesFromInner() const;
 	[[nodiscard]] rpl::producer<ScrollToRequest> scrollToRequests() const;
 
@@ -157,6 +160,9 @@ private:
 	bool _lastSelectedByMouse = false;
 	bool _pressedOutside = false;
 
+	int _motions = 0;
+	QPoint _mousePopupPosition;
+
 	QPointer<QAction> _childShownAction;
 
 	rpl::event_stream<> _resizesFromInner;
