@@ -41,6 +41,10 @@ public:
 	PopupMenu(QWidget *parent, QMenu *menu, const style::PopupMenu &st = st::defaultPopupMenu);
 	~PopupMenu();
 
+	QAccessible::Role accessibilityRole() override {
+		return QAccessible::Role::PopupMenu;
+	}
+
 	[[nodiscard]] const style::PopupMenu &st() const {
 		return _st;
 	}
@@ -80,6 +84,9 @@ public:
 
 	void deleteOnHide(bool del);
 	void popup(const QPoint &p);
+	[[nodiscard]] static QPoint ConstrainToParentScreen(
+		not_null<PopupMenu*> menu,
+		QPoint globalPos);
 	bool prepareGeometryFor(const QPoint &p);
 	void popupPrepared();
 	void hideMenu(bool fast = false);
